@@ -1,4 +1,7 @@
-use fish_build_helper::{env_var, fish_build_dir, workspace_root};
+use fish_build_helper::{
+    env_var, fish_build_dir, target_os, target_os_is_apple, target_os_is_bsd, target_os_is_cygwin,
+    workspace_root,
+};
 use rsconf::Target;
 use std::env;
 use std::path::{Path, PathBuf};
@@ -40,14 +43,7 @@ fn main() {
     // safety: single-threaded code.
     unsafe { std::env::set_var("FISH_BUILD_VERSION", version) };
 
-    // These are necessary if built with embedded functions,
-    // but only in release builds (because rust-embed in debug builds reads from the filesystem).
-    #[cfg(feature = "embed-data")]
-    #[cfg(any(windows, not(debug_assertions)))]
-    rsconf::rebuild_if_path_changed("share");
-
-    #[cfg(feature = "gettext-extract")]
-    rsconf::rebuild_if_env_changed("FISH_GETTEXT_EXTRACTION_FILE");
+    fish_build_helper::rebuild_if_embedded_path_changed("share");
 
     let build = cc::Build::new();
     let mut target = Target::new_from(build).unwrap();
@@ -73,37 +69,41 @@ fn main() {
 /// `Cargo.toml`) behind a feature we just enabled.
 ///
 /// [0]: https://github.com/rust-lang/cargo/issues/5499
-#[rustfmt::skip]
 fn detect_cfgs(target: &mut Target) {
     for (name, handler) in [
-        // Ignore the first entry, it just sets up the type inference. Model new entries after the
-        // second line.
+        // Ignore the first entry, it just sets up the type inference.
         ("", &(|_: &Target| false) as &dyn Fn(&Target) -> bool),
-        ("apple", &detect_apple),
-        ("bsd", &detect_bsd),
-        ("using_cmake", &|_| option_env!("FISH_CMAKE_BINARY_DIR").is_some()),
-        ("use_prebuilt_docs", &|_| env_var("FISH_USE_PREBUILT_DOCS").is_some_and(|v| v == "TRUE") ),
-        ("cygwin", &detect_cygwin),
-        ("small_main_stack", &has_small_stack),
-        // See if libc supports the thread-safe localeconv_l(3) alternative to localeconv(3).
-        ("localeconv_l", &|target| {
-            target.has_symbol("localeconv_l")
-        }),
-        ("FISH_USE_POSIX_SPAWN", &|target| {
-            target.has_header("spawn.h")
-        }),
-        ("HAVE_PIPE2", &|target| {
-            target.has_symbol("pipe2")
-        }),
-        ("HAVE_EVENTFD", &|target| {
+        ("apple", &(|_| target_os_is_apple())),
+        ("bsd", &(|_| target_os_is_bsd())),
+        ("cygwin", &(|_| target_os_is_cygwin())),
+        ("have_eventfd", &|target| {
             // FIXME: NetBSD 10 has eventfd, but the libc crate does not expose it.
-            if cfg!(target_os = "netbsd") {
-                 false
-             } else {
-                 target.has_header("sys/eventfd.h")
+            if target_os() == "netbsd" {
+                false
+            } else {
+                target.has_header("sys/eventfd.h")
             }
         }),
-        ("HAVE_WAITSTATUS_SIGNAL_RET", &|target| {
+        ("have_localeconv_l", &|target| {
+            target.has_symbol("localeconv_l")
+        }),
+        ("have_pipe2", &|target| target.has_symbol("pipe2")),
+        ("have_posix_spawn", &|target| {
+            if matches!(target_os().as_str(), "openbsd" | "android") {
+                // OpenBSD's posix_spawn returns status 127 instead of erroring with ENOEXEC when faced with a
+                // shebang-less script. Disable posix_spawn on OpenBSD.
+                //
+                // Android is broken for unclear reasons
+                false
+            } else {
+                target.has_header("spawn.h")
+            }
+        }),
+        ("small_main_stack", &has_small_stack),
+        ("using_cmake", &|_| {
+            option_env!("FISH_CMAKE_BINARY_DIR").is_some()
+        }),
+        ("waitstatus_signal_ret", &|target| {
             target.r#if("WEXITSTATUS(0x007f) == 0x7f", &["sys/wait.h"])
         }),
     ] {
@@ -111,39 +111,6 @@ fn detect_cfgs(target: &mut Target) {
     }
 }
 
-fn detect_apple(_: &Target) -> bool {
-    cfg!(any(target_os = "ios", target_os = "macos"))
-}
-
-fn detect_cygwin(_: &Target) -> bool {
-    // Cygwin target is usually cross-compiled.
-    env_var("CARGO_CFG_TARGET_OS").unwrap() == "cygwin"
-}
-
-/// Detect if we're being compiled for a BSD-derived OS, allowing targeting code conditionally with
-/// `#[cfg(bsd)]`.
-///
-/// Rust offers fine-grained conditional compilation per-os for the popular operating systems, but
-/// doesn't necessarily include less-popular forks nor does it group them into families more
-/// specific than "windows" vs "unix" so we can conditionally compile code for BSD systems.
-fn detect_bsd(_: &Target) -> bool {
-    // Instead of using `uname`, we can inspect the TARGET env variable set by Cargo. This lets us
-    // support cross-compilation scenarios.
-    let mut target = env_var("TARGET").unwrap();
-    if !target.chars().all(|c| c.is_ascii_lowercase()) {
-        target = target.to_ascii_lowercase();
-    }
-    let is_bsd = target.ends_with("bsd") || target.ends_with("dragonfly");
-    #[cfg(any(
-        target_os = "dragonfly",
-        target_os = "freebsd",
-        target_os = "netbsd",
-        target_os = "openbsd",
-    ))]
-    assert!(is_bsd, "Target incorrectly detected as not BSD!");
-    is_bsd
-}
-
 /// Rust sets the stack size of newly created threads to a sane value, but is at at the mercy of the
 /// OS when it comes to the size of the main stack. Some platforms we support default to a tiny
 /// 0.5 MiB main stack, which is insufficient for fish's MAX_EVAL_DEPTH/MAX_STACK_DEPTH values.
@@ -210,32 +177,18 @@ fn setup_paths() {
     overridable_path("SYSCONFDIR", |env_sysconfdir| {
         Some(join_if_relative(
             &prefix,
-            env_sysconfdir.unwrap_or(
-                // Embedded builds use "/etc," not "$PREFIX/etc".
-                if cfg!(feature = "embed-data") {
-                    "/etc/"
-                } else {
-                    "etc/"
-                }
-                .to_string(),
-            ),
+            env_sysconfdir.unwrap_or("/etc/".to_string()),
         ))
     });
 
-    let default_ok = !cfg!(feature = "embed-data");
     let datadir = overridable_path("DATADIR", |env_datadir| {
-        let default = default_ok.then_some("share/".to_string());
-        env_datadir
-            .or(default)
-            .map(|p| join_if_relative(&prefix, p))
+        env_datadir.map(|p| join_if_relative(&prefix, p))
     });
     overridable_path("BINDIR", |env_bindir| {
-        let default = default_ok.then_some("bin/".to_string());
-        env_bindir.or(default).map(|p| join_if_relative(&prefix, p))
+        env_bindir.map(|p| join_if_relative(&prefix, p))
     });
     overridable_path("DOCDIR", |env_docdir| {
-        let default = default_ok.then_some("doc/fish".to_string());
-        env_docdir.or(default).map(|p| {
+        env_docdir.map(|p| {
             join_if_relative(
                 &datadir
                     .expect("Setting DOCDIR without setting DATADIR is not currently supported"),
