@@ -39,7 +39,7 @@ pub fn cd(parser: &Parser, streams: &mut IoStreams, args: &mut [&wstr]) -> Built
             None => {
                 streams
                     .err
-                    .append(wgettext_fmt!("%s: Could not find home directory\n", cmd));
+                    .append(&wgettext_fmt!("%s: Could not find home directory\n", cmd));
                 return Err(STATUS_CMD_ERROR);
             }
         }
@@ -47,13 +47,13 @@ pub fn cd(parser: &Parser, streams: &mut IoStreams, args: &mut [&wstr]) -> Built
 
     // Stop `cd ""` from crashing
     if dir_in.is_empty() {
-        streams.err.append(wgettext_fmt!(
+        streams.err.append(&wgettext_fmt!(
             "%s: Empty directory '%s' does not exist\n",
             cmd,
             dir_in
         ));
         if !parser.is_interactive() {
-            streams.err.append(parser.current_line());
+            streams.err.append(&parser.current_line());
         };
         return Err(STATUS_CMD_ERROR);
     }
@@ -62,14 +62,14 @@ pub fn cd(parser: &Parser, streams: &mut IoStreams, args: &mut [&wstr]) -> Built
 
     let dirs = path_apply_cdpath(dir_in, &pwd, vars);
     if dirs.is_empty() {
-        streams.err.append(wgettext_fmt!(
+        streams.err.append(&wgettext_fmt!(
             "%s: The directory '%s' does not exist\n",
             cmd,
             dir_in
         ));
 
         if !parser.is_interactive() {
-            streams.err.append(parser.current_line());
+            streams.err.append(&parser.current_line());
         }
 
         return Err(STATUS_CMD_ERROR);
@@ -134,22 +134,22 @@ pub fn cd(parser: &Parser, streams: &mut IoStreams, args: &mut [&wstr]) -> Built
     if best_errno == ENOTDIR {
         streams
             .err
-            .append(wgettext_fmt!("%s: '%s' is not a directory\n", cmd, dir_in));
+            .append(&wgettext_fmt!("%s: '%s' is not a directory\n", cmd, dir_in));
     } else if !broken_symlink.is_empty() {
-        streams.err.append(wgettext_fmt!(
+        streams.err.append(&wgettext_fmt!(
             "%s: '%s' is a broken symbolic link to '%s'\n",
             cmd,
             broken_symlink,
             broken_symlink_target
         ));
     } else if best_errno == ELOOP {
-        streams.err.append(wgettext_fmt!(
+        streams.err.append(&wgettext_fmt!(
             "%s: Too many levels of symbolic links: '%s'\n",
             cmd,
             dir_in
         ));
     } else if best_errno == ENOENT {
-        streams.err.append(wgettext_fmt!(
+        streams.err.append(&wgettext_fmt!(
             "%s: The directory '%s' does not exist\n",
             cmd,
             dir_in
@@ -157,11 +157,11 @@ pub fn cd(parser: &Parser, streams: &mut IoStreams, args: &mut [&wstr]) -> Built
     } else if best_errno == EACCES || best_errno == EPERM {
         streams
             .err
-            .append(wgettext_fmt!("%s: Permission denied: '%s'\n", cmd, dir_in));
+            .append(&wgettext_fmt!("%s: Permission denied: '%s'\n", cmd, dir_in));
     } else {
         errno::set_errno(Errno(best_errno));
         wperror(L!("cd"));
-        streams.err.append(wgettext_fmt!(
+        streams.err.append(&wgettext_fmt!(
             "%s: Unknown error trying to locate directory '%s'\n",
             cmd,
             dir_in
@@ -169,8 +169,8 @@ pub fn cd(parser: &Parser, streams: &mut IoStreams, args: &mut [&wstr]) -> Built
     }
 
     if !parser.is_interactive() {
-        streams.err.append(parser.current_line());
+        streams.err.append(&parser.current_line());
     }
 
-    return Err(STATUS_CMD_ERROR);
+    Err(STATUS_CMD_ERROR)
 }
