@@ -37,7 +37,7 @@ pub fn fg(parser: &Parser, streams: &mut IoStreams, argv: &mut [&wstr]) -> Built
             None => {
                 streams
                     .err
-                    .append(wgettext_fmt!("%s: There are no suitable jobs\n", cmd));
+                    .append(&wgettext_fmt!("%s: There are no suitable jobs\n", cmd));
                 return Err(STATUS_INVALID_ARGS);
             }
             Some((pos, j)) => {
@@ -57,11 +57,11 @@ pub fn fg(parser: &Parser, streams: &mut IoStreams, argv: &mut [&wstr]) -> Built
         if found_job {
             streams
                 .err
-                .append(wgettext_fmt!("%s: Ambiguous job\n", cmd));
+                .append(&wgettext_fmt!("%s: Ambiguous job\n", cmd));
         } else {
             streams
                 .err
-                .append(wgettext_fmt!("%s: '%s' is not a job\n", cmd, argv[optind]));
+                .append(&wgettext_fmt!("%s: '%s' is not a job\n", cmd, argv[optind]));
         }
 
         builtin_print_error_trailer(parser, streams.err, cmd);
@@ -76,14 +76,14 @@ pub fn fg(parser: &Parser, streams: &mut IoStreams, argv: &mut [&wstr]) -> Built
                 {
                     streams
                         .err
-                        .append(wgettext_fmt!("%s: No suitable job: %d\n", cmd, pid));
+                        .append(&wgettext_fmt!("%s: No suitable job: %d\n", cmd, pid));
                     job_pos = None;
                     job = None
                 } else {
                     let (pos, j) = j.unwrap();
                     job_pos = Some(pos);
                     job = if !j.wants_job_control() {
-                        streams.err.append(wgettext_fmt!(
+                        streams.err.append(&wgettext_fmt!(
                                         "%s: Can't put job %d, '%s' to foreground because it is not under job control\n",
                                         cmd,
                                         pid,
@@ -111,7 +111,7 @@ pub fn fg(parser: &Parser, streams: &mut IoStreams, argv: &mut [&wstr]) -> Built
     if streams.err_is_redirected {
         streams
             .err
-            .append(wgettext_fmt!(FG_MSG, job.job_id(), job.command()));
+            .append(&wgettext_fmt!(FG_MSG, job.job_id(), job.command()));
     } else {
         // If we aren't redirecting, send output to real stderr, since stuff in sb_err won't get
         // printed until the command finishes.
@@ -151,7 +151,7 @@ pub fn fg(parser: &Parser, streams: &mut IoStreams, argv: &mut [&wstr]) -> Built
     handoff.to_job_group(job.group.as_ref().unwrap());
     let resumed = job.resume();
     if resumed {
-        job.continue_job(parser);
+        job.continue_job(parser, /*block_io=*/ None);
     }
     if job.is_stopped() {
         handoff.save_tty_modes();
