@@ -15,6 +15,7 @@ use crate::expand::expand_escape_string;
 use crate::expand::expand_escape_variable;
 use crate::history::History;
 use crate::history::history_session_id;
+use crate::parse_execution::varname_error;
 use crate::{
     env::{EnvMode, EnvVar, Environment},
     wutil::wcstoi::wcstoi_partial,
@@ -183,8 +184,9 @@ impl Options {
                     // implicit drop(w); here
                     if args[optind - 1].starts_with("-o") {
                         // TODO: translate this
-                        streams.err.appendln(L!(
-                            "Fish does not have shell options. See `help fish-for-bash-users`."
+                        streams.err.appendln(sprintf!(
+                            "Fish does not have shell options. See `help %s`.",
+                            help_section!("fish_for_bash_users")
                         ));
                         if optind < args.len() {
                             if args[optind] == "vi" {
@@ -230,14 +232,14 @@ impl Options {
     ) -> Result<(), ErrorCode> {
         // Can't query and erase or list.
         if opts.query && (opts.erase || opts.list) {
-            streams.err.append(wgettext_fmt!(BUILTIN_ERR_COMBO, cmd));
+            streams.err.append(&wgettext_fmt!(BUILTIN_ERR_COMBO, cmd));
             builtin_print_error_trailer(parser, streams.err, cmd);
             return Err(STATUS_INVALID_ARGS);
         }
 
         // We can't both list and erase variables.
         if opts.erase && opts.list {
-            streams.err.append(wgettext_fmt!(BUILTIN_ERR_COMBO, cmd));
+            streams.err.append(&wgettext_fmt!(BUILTIN_ERR_COMBO, cmd));
             builtin_print_error_trailer(parser, streams.err, cmd);
             return Err(STATUS_INVALID_ARGS);
         }
@@ -251,14 +253,16 @@ impl Options {
             // ..unless we are erasing a variable, in which case we can erase from several in one go.
             && !opts.erase
         {
-            streams.err.append(wgettext_fmt!(BUILTIN_ERR_GLOCAL, cmd));
+            streams.err.append(&wgettext_fmt!(BUILTIN_ERR_GLOCAL, cmd));
             builtin_print_error_trailer(parser, streams.err, cmd);
             return Err(STATUS_INVALID_ARGS);
         }
 
         // Variables can only have one export status.
         if opts.exportv && opts.unexport {
-            streams.err.append(wgettext_fmt!(BUILTIN_ERR_EXPUNEXP, cmd));
+            streams
+                .err
+                .append(&wgettext_fmt!(BUILTIN_ERR_EXPUNEXP, cmd));
             builtin_print_error_trailer(parser, streams.err, cmd);
             return Err(STATUS_INVALID_ARGS);
         }
@@ -267,14 +271,14 @@ impl Options {
         if opts.pathvar && opts.unpathvar {
             streams
                 .err
-                .append(wgettext_fmt!(BUILTIN_ERR_PATHUNPATH, cmd));
+                .append(&wgettext_fmt!(BUILTIN_ERR_PATHUNPATH, cmd));
             builtin_print_error_trailer(parser, streams.err, cmd);
             return Err(STATUS_INVALID_ARGS);
         }
 
         // Trying to erase and (un)export at the same time doesn't make sense.
         if opts.erase && (opts.exportv || opts.unexport) {
-            streams.err.append(wgettext_fmt!(BUILTIN_ERR_COMBO, cmd));
+            streams.err.append(&wgettext_fmt!(BUILTIN_ERR_COMBO, cmd));
             builtin_print_error_trailer(parser, streams.err, cmd);
             return Err(STATUS_INVALID_ARGS);
         }
@@ -289,7 +293,7 @@ impl Options {
                 || opts.exportv
                 || opts.universal)
         {
-            streams.err.append(wgettext_fmt!(BUILTIN_ERR_COMBO, cmd));
+            streams.err.append(&wgettext_fmt!(BUILTIN_ERR_COMBO, cmd));
             builtin_print_error_trailer(parser, streams.err, cmd);
             return Err(STATUS_INVALID_ARGS);
         }
@@ -297,7 +301,7 @@ impl Options {
         if args.len() == optind && opts.erase {
             streams
                 .err
-                .append(wgettext_fmt!(BUILTIN_ERR_MISSING, cmd, L!("--erase")));
+                .append(&wgettext_fmt!(BUILTIN_ERR_MISSING, cmd, L!("--erase")));
             builtin_print_error_trailer(parser, streams.err, cmd);
             return Err(STATUS_INVALID_ARGS);
         }
@@ -319,7 +323,7 @@ fn warn_if_uvar_shadows_global(
         && parser.is_interactive()
         && parser.vars().getf(dest, EnvMode::GLOBAL).is_some()
     {
-        streams.err.append(wgettext_fmt!(UVAR_ERR, cmd, dest));
+        streams.err.append(&wgettext_fmt!(UVAR_ERR, cmd, dest));
     }
 }
 
@@ -327,28 +331,28 @@ fn handle_env_return(retval: EnvStackSetResult, cmd: &wstr, key: &wstr, streams:
     match retval {
         EnvStackSetResult::Ok => (),
         EnvStackSetResult::Perm => {
-            streams.err.append(wgettext_fmt!(
+            streams.err.append(&wgettext_fmt!(
                 "%s: Tried to change the read-only variable '%s'\n",
                 cmd,
                 key
             ));
         }
         EnvStackSetResult::Scope => {
-            streams.err.append(wgettext_fmt!(
+            streams.err.append(&wgettext_fmt!(
                 "%s: Tried to modify the special variable '%s' with the wrong scope\n",
                 cmd,
                 key
             ));
         }
         EnvStackSetResult::Invalid => {
-            streams.err.append(wgettext_fmt!(
+            streams.err.append(&wgettext_fmt!(
                 "%s: Tried to modify the special variable '%s' to an invalid value\n",
                 cmd,
                 key
             ));
         }
         EnvStackSetResult::NotFound => {
-            streams.err.append(wgettext_fmt!(
+            streams.err.append(&wgettext_fmt!(
                 "%s: The variable '%s' does not exist\n",
                 cmd,
                 key
@@ -428,7 +432,7 @@ fn split_var_and_indexes<'a>(
     match split_var_and_indexes_internal(arg, mode, vars) {
         Ok(split) => Some(split),
         Err(EnvArrayParseError::InvalidIndex(varname)) => {
-            streams.err.append(wgettext_fmt!(
+            streams.err.append(&wgettext_fmt!(
                 "%s: Invalid index starting at '%s'\n",
                 "set",
                 &varname,
@@ -445,7 +449,7 @@ fn split_var_and_indexes_internal<'a>(
 ) -> Result<SplitVar<'a>, EnvArrayParseError> {
     let mut res = SplitVar::default();
     let open_bracket = arg.find_char('[');
-    res.varname = open_bracket.map(|b| &arg[..b]).unwrap_or(arg);
+    res.varname = open_bracket.map_or(arg, |b| &arg[..b]);
     res.var = vars.getf(res.varname, mode);
     let Some(open_bracket) = open_bracket else {
         // Common case of no bracket
@@ -588,7 +592,7 @@ fn list(opts: &Options, parser: &Parser, streams: &mut IoStreams) -> BuiltinResu
         }
 
         out.push('\n');
-        streams.out.append(out);
+        streams.out.append(&out);
     }
 
     Ok(SUCCESS)
@@ -657,7 +661,7 @@ fn show_scope(var_name: &wstr, scope: EnvMode, streams: &mut IoStreams, vars: &d
         L!("")
     };
     let vals = var.as_list();
-    streams.out.append(wgettext_fmt!(
+    streams.out.append(&wgettext_fmt!(
         "$%s: set in %s scope, %s,%s with %d elements",
         var_name,
         scope_name,
@@ -670,7 +674,7 @@ fn show_scope(var_name: &wstr, scope: EnvMode, streams: &mut IoStreams, vars: &d
     if EnvVar::flags_for(var_name).contains(EnvVarFlags::READ_ONLY) {
         streams.out.append(wgettext!(" (read-only)\n"));
     } else {
-        streams.out.push('\n');
+        streams.out.append_char('\n');
     }
 
     for i in 0..vals.len() {
@@ -682,7 +686,7 @@ fn show_scope(var_name: &wstr, scope: EnvMode, streams: &mut IoStreams, vars: &d
                 } else {
                     get_ellipsis_str()
                 });
-                streams.out.push('\n');
+                streams.out.append_char('\n');
             }
             if i >= 50 && i < vals.len() - 50 {
                 continue;
@@ -695,7 +699,7 @@ fn show_scope(var_name: &wstr, scope: EnvMode, streams: &mut IoStreams, vars: &d
         );
         streams
             .out
-            .append(sprintf!("$%s[%d]: |%s|\n", var_name, i + 1, &escaped_val));
+            .append(&sprintf!("$%s[%d]: |%s|\n", var_name, i + 1, &escaped_val));
     }
 }
 
@@ -720,7 +724,7 @@ fn show(cmd: &wstr, parser: &Parser, streams: &mut IoStreams, args: &[&wstr]) ->
                     inherited,
                     EscapeStringStyle::Script(EscapeFlags::NO_PRINTABLES | EscapeFlags::NO_QUOTED),
                 );
-                streams.out.append(wgettext_fmt!(
+                streams.out.append(&wgettext_fmt!(
                     "$%s: originally inherited as |%s|\n",
                     name,
                     escaped_val
@@ -730,15 +734,13 @@ fn show(cmd: &wstr, parser: &Parser, streams: &mut IoStreams, args: &[&wstr]) ->
     } else {
         for arg in args.iter().copied() {
             if !valid_var_name(arg) {
-                streams
-                    .err
-                    .append(wgettext_fmt!(BUILTIN_ERR_VARNAME, cmd, arg));
+                streams.err.append(&varname_error(cmd, arg));
                 builtin_print_error_trailer(parser, streams.err, cmd);
                 return Err(STATUS_INVALID_ARGS);
             }
 
             if arg.contains('[') {
-                streams.err.append(wgettext_fmt!(
+                streams.err.append(&wgettext_fmt!(
                     "%s: `set --show` does not allow slices with the var names\n",
                     cmd
                 ));
@@ -754,7 +756,7 @@ fn show(cmd: &wstr, parser: &Parser, streams: &mut IoStreams, args: &[&wstr]) ->
                     inherited,
                     EscapeStringStyle::Script(EscapeFlags::NO_PRINTABLES | EscapeFlags::NO_QUOTED),
                 );
-                streams.out.append(wgettext_fmt!(
+                streams.out.append(&wgettext_fmt!(
                     "$%s: originally inherited as |%s|\n",
                     arg,
                     escaped_val
@@ -788,9 +790,7 @@ fn erase(
             };
 
             if !valid_var_name(split.varname) {
-                streams
-                    .err
-                    .append(wgettext_fmt!(BUILTIN_ERR_VARNAME, cmd, split.varname));
+                streams.err.append(&varname_error(cmd, split.varname));
                 builtin_print_error_trailer(parser, streams.err, cmd);
                 return Err(STATUS_INVALID_ARGS);
             }
@@ -911,7 +911,7 @@ fn set_internal(
     if argv.is_empty() {
         streams
             .err
-            .append(wgettext_fmt!(BUILTIN_ERR_MIN_ARG_COUNT1, cmd, 1));
+            .append(&wgettext_fmt!(BUILTIN_ERR_MIN_ARG_COUNT1, cmd, 1));
         builtin_print_error_trailer(parser, streams.err, cmd);
         return Err(STATUS_INVALID_ARGS);
     }
@@ -927,11 +927,9 @@ fn set_internal(
 
     // Is the variable valid?
     if !valid_var_name(split.varname) {
-        streams
-            .err
-            .append(wgettext_fmt!(BUILTIN_ERR_VARNAME, cmd, split.varname));
+        streams.err.append(&varname_error(cmd, split.varname));
         if let Some(pos) = split.varname.chars().position(|c| c == '=') {
-            streams.err.append(wgettext_fmt!(
+            streams.err.append(&wgettext_fmt!(
                 "%s: Did you mean `set %s %s`?",
                 cmd,
                 &escape(&split.varname[..pos]),
@@ -949,14 +947,14 @@ fn set_internal(
             if *ind <= 0 {
                 streams
                     .err
-                    .append(wgettext_fmt!("%s: array index out of bounds\n", cmd));
+                    .append(&wgettext_fmt!("%s: array index out of bounds\n", cmd));
                 builtin_print_error_trailer(parser, streams.err, cmd);
                 return Err(STATUS_INVALID_ARGS);
             }
         }
         // Append and prepend are disallowed.
         if opts.append || opts.prepend {
-            streams.err.append(wgettext_fmt!(
+            streams.err.append(&wgettext_fmt!(
                 "%s: Cannot use --append or --prepend when assigning to a slice",
                 cmd
             ));
@@ -966,7 +964,7 @@ fn set_internal(
 
         // Argument count and index count must agree.
         if split.indexes.len() != argv.len() {
-            streams.err.append(wgettext_fmt!(
+            streams.err.append(&wgettext_fmt!(
                 MISMATCHED_ARGS,
                 cmd,
                 split.indexes.len(),
@@ -1025,5 +1023,5 @@ pub fn set(parser: &Parser, streams: &mut IoStreams, args: &mut [&wstr]) -> Buil
         });
     }
 
-    return retval;
+    retval
 }
