@@ -1,15 +1,13 @@
 use super::prelude::*;
-use crate::builtins::*;
-use crate::common::{escape, get_by_sorted_name, str2wcstring, Named};
+use crate::common::{Named, bytes2wcstring, escape, get_by_sorted_name};
 use crate::io::OutputStream;
 use crate::parse_constants::UNKNOWN_BUILTIN_ERR_MSG;
 use crate::parse_util::parse_util_argument_is_help;
-use crate::parser::{Block, BlockType, LoopStatus};
-use crate::proc::{no_exec, ProcStatus};
-use crate::reader::reader_read;
-use crate::wchar::L;
+use crate::parser::{BlockType, LoopStatus};
+use crate::proc::{Pid, ProcStatus, no_exec};
+use crate::{builtins::*, wutil};
 use errno::errno;
-use libc::STDIN_FILENO;
+use fish_wchar::L;
 
 use std::fs::File;
 use std::io::{BufRead, BufReader, Read};
@@ -24,84 +22,87 @@ pub const DEFAULT_READ_PROMPT: &wstr =
 localizable_consts!(
     /// Error message on missing argument.
     pub BUILTIN_ERR_MISSING
-    "%ls: %ls: option requires an argument\n"
+    "%s: %s: option requires an argument\n"
 
     /// Error message on unexpected argument.
     pub BUILTIN_ERR_UNEXP_ARG
-    "%ls: %ls: option does not take an argument\n"
+    "%s: %s: option does not take an argument\n"
 
     /// Error message on missing man page.
     pub BUILTIN_ERR_MISSING_HELP
-    "fish: %ls: missing man page\nDocumentation may not be installed.\n`help %ls` will show an online version\n"
+    "fish: %s: missing man page\nDocumentation may not be installed.\n`help %s` will show an online version\n"
 
     /// Error message on multiple scope levels for variables.
     pub BUILTIN_ERR_GLOCAL
-    "%ls: scope can be only one of: universal function global local\n"
+    "%s: scope can be only one of: universal function global local\n"
 
     /// Error message for specifying both export and unexport to set/read.
     pub BUILTIN_ERR_EXPUNEXP
-    "%ls: cannot both export and unexport\n"
+    "%s: cannot both export and unexport\n"
 
     /// Error message for specifying both path and unpath to set/read.
     pub BUILTIN_ERR_PATHUNPATH
-    "%ls: cannot both path and unpath\n"
+    "%s: cannot both path and unpath\n"
 
     /// Error message for unknown switch.
     pub BUILTIN_ERR_UNKNOWN
-    "%ls: %ls: unknown option\n"
+    "%s: %s: unknown option\n"
 
     /// Error message for invalid bind mode name.
     pub BUILTIN_ERR_BIND_MODE
-    "%ls: %ls: invalid mode name. See `help identifiers`\n"
+    "%s: %s: invalid mode name. See `help %s`\n"
 
     /// Error message when too many arguments are supplied to a builtin.
     pub BUILTIN_ERR_TOO_MANY_ARGUMENTS
-    "%ls: too many arguments\n"
+    "%s: too many arguments\n"
 
     /// Error message when integer expected
     pub BUILTIN_ERR_NOT_NUMBER
-    "%ls: %ls: invalid integer\n"
+    "%s: %s: invalid integer\n"
 
     /// Command that requires a subcommand was invoked without a recognized subcommand.
     pub BUILTIN_ERR_MISSING_SUBCMD
-    "%ls: missing subcommand\n"
+    "%s: missing subcommand\n"
 
     pub BUILTIN_ERR_INVALID_SUBCMD
-    "%ls: %ls: invalid subcommand\n"
+    "%s: %s: invalid subcommand\n"
+
+    pub BUILTIN_ERR_INVALID_SUBSUBCMD
+    "%s %s: %s: invalid subcommand\n"
 
     /// Error messages for unexpected args.
     pub BUILTIN_ERR_ARG_COUNT0
-    "%ls: missing argument\n"
+    "%s: missing argument\n"
 
     pub BUILTIN_ERR_ARG_COUNT1
-    "%ls: expected %d arguments; got %d\n"
+    "%s: expected %d arguments; got %d\n"
 
     pub BUILTIN_ERR_ARG_COUNT2
-    "%ls: %ls: expected %d arguments; got %d\n"
+    "%s: %s: expected %d arguments; got %d\n"
 
     pub BUILTIN_ERR_MIN_ARG_COUNT1
-    "%ls: expected >= %d arguments; got %d\n"
+    "%s: expected >= %d arguments; got %d\n"
 
     pub BUILTIN_ERR_MAX_ARG_COUNT1
-    "%ls: expected <= %d arguments; got %d\n"
+    "%s: expected <= %d arguments; got %d\n"
 
     /// Error message for invalid variable name.
     pub BUILTIN_ERR_VARNAME
-    "%ls: %ls: invalid variable name. See `help identifiers`\n"
+    "%s: %s: invalid variable name. See `help %s`\n"
 
     /// Error message on invalid combination of options.
     pub BUILTIN_ERR_COMBO
-    "%ls: invalid option combination\n"
+    "%s: invalid option combination\n"
 
     pub BUILTIN_ERR_COMBO2
-    "%ls: invalid option combination, %ls\n"
+    "%s: invalid option combination, %s\n"
 
     pub BUILTIN_ERR_COMBO2_EXCLUSIVE
-    "%ls: %ls %ls: options cannot be used together\n"
+    "%s: %s %s: options cannot be used together\n"
 
     /// The send stuff to foreground message.
     pub FG_MSG
-    "Send job %d (%ls) to foreground\n"
+    "Send job %d (%s) to foreground\n"
 );
 
 // Return values (`$status` values for fish scripts) for various situations.
@@ -127,11 +128,7 @@ pub trait BuiltinResultExt {
 
 impl BuiltinResultExt for BuiltinResult {
     fn from_dynamic(code: c_int) -> Self {
-        if code == 0 {
-            Ok(SUCCESS)
-        } else {
-            Err(code)
-        }
+        if code == 0 { Ok(SUCCESS) } else { Err(code) }
     }
     fn builtin_status_code(&self) -> c_int {
         match self {
@@ -193,7 +190,7 @@ const BUILTIN_DATAS: &[BuiltinData] = &[
     },
     BuiltinData {
         name: L!(":"),
-        func: builtin_true,
+        func: r#true::r#true,
     },
     BuiltinData {
         name: L!("["), // ]
@@ -201,7 +198,7 @@ const BUILTIN_DATAS: &[BuiltinData] = &[
     },
     BuiltinData {
         name: L!("_"),
-        func: builtin_gettext,
+        func: gettext::gettext,
     },
     BuiltinData {
         name: L!("abbr"),
@@ -233,11 +230,11 @@ const BUILTIN_DATAS: &[BuiltinData] = &[
     },
     BuiltinData {
         name: L!("break"),
-        func: builtin_break_continue,
+        func: r#break::r#break,
     },
     BuiltinData {
         name: L!("breakpoint"),
-        func: builtin_breakpoint,
+        func: breakpoint::breakpoint,
     },
     BuiltinData {
         name: L!("builtin"),
@@ -269,7 +266,7 @@ const BUILTIN_DATAS: &[BuiltinData] = &[
     },
     BuiltinData {
         name: L!("continue"),
-        func: builtin_break_continue,
+        func: r#continue::r#continue,
     },
     BuiltinData {
         name: L!("count"),
@@ -309,7 +306,7 @@ const BUILTIN_DATAS: &[BuiltinData] = &[
     },
     BuiltinData {
         name: L!("false"),
-        func: builtin_false,
+        func: r#false::r#false,
     },
     BuiltinData {
         name: L!("fg"),
@@ -421,7 +418,7 @@ const BUILTIN_DATAS: &[BuiltinData] = &[
     },
     BuiltinData {
         name: L!("true"),
-        func: builtin_true,
+        func: r#true::r#true,
     },
     BuiltinData {
         name: L!("type"),
@@ -486,7 +483,7 @@ pub fn builtin_run(parser: &Parser, argv: &mut [&wstr], streams: &mut IoStreams)
     }
 
     let Some(builtin) = builtin_lookup(argv[0]) else {
-        FLOGF!(error, "%s", wgettext_fmt!(UNKNOWN_BUILTIN_ERR_MSG, argv[0]));
+        flogf!(error, "%s", wgettext_fmt!(UNKNOWN_BUILTIN_ERR_MSG, argv[0]));
         return ProcStatus::from_exit_code(STATUS_CMD_ERROR);
     };
 
@@ -528,9 +525,9 @@ pub fn builtin_run(parser: &Parser, argv: &mut [&wstr], streams: &mut IoStreams)
         // would assert() out, which is a terrible failure mode
         // So instead, what we do is we get a positive code,
         // and we avoid 0.
-        FLOGF!(
+        flogf!(
             warning,
-            "builtin %ls returned invalid exit code %d",
+            "builtin %s returned invalid exit code %d",
             argv[0],
             code
         );
@@ -631,12 +628,12 @@ pub fn builtin_print_help(parser: &Parser, streams: &mut IoStreams, cmd: &wstr)
         return;
     }
     let name_esc = escape(cmd);
-    let cmd = sprintf!("__fish_print_help %ls ", &name_esc);
+    let cmd = sprintf!("__fish_print_help %s ", &name_esc);
     let res = parser.eval(&cmd, streams.io_chain);
     if res.status.normal_exited() && res.status.exit_code() == 2 {
         streams
             .err
-            .append(wgettext_fmt!(BUILTIN_ERR_MISSING_HELP, name_esc, name_esc));
+            .append(&wgettext_fmt!(BUILTIN_ERR_MISSING_HELP, name_esc, name_esc));
     }
 }
 
@@ -650,7 +647,7 @@ pub fn builtin_unknown_option(
 ) {
     streams
         .err
-        .append(wgettext_fmt!(BUILTIN_ERR_UNKNOWN, cmd, opt));
+        .append(&wgettext_fmt!(BUILTIN_ERR_UNKNOWN, cmd, opt));
     if print_hints {
         builtin_print_error_trailer(parser, streams.err, cmd);
     }
@@ -667,7 +664,7 @@ pub fn builtin_missing_argument(
     if opt.char_at(0) == '-' && opt.char_at(1) != '-' {
         // if c in -qc '-qc' is missing the argument, now opt is just 'c'
         opt = &opt[opt.len() - 1..];
-        streams.err.append(wgettext_fmt!(
+        streams.err.append(&wgettext_fmt!(
             BUILTIN_ERR_MISSING,
             cmd,
             L!("-").to_owned() + opt
@@ -675,7 +672,7 @@ pub fn builtin_missing_argument(
     } else {
         streams
             .err
-            .append(wgettext_fmt!(BUILTIN_ERR_MISSING, cmd, opt));
+            .append(&wgettext_fmt!(BUILTIN_ERR_MISSING, cmd, opt));
     }
     if print_hints {
         builtin_print_error_trailer(parser, streams.err, cmd);
@@ -692,7 +689,7 @@ pub fn builtin_unexpected_argument(
 ) {
     streams
         .err
-        .append(wgettext_fmt!(BUILTIN_ERR_UNEXP_ARG, cmd, opt));
+        .append(&wgettext_fmt!(BUILTIN_ERR_UNEXP_ARG, cmd, opt));
     if print_hints {
         builtin_print_error_trailer(parser, streams.err, cmd);
     }
@@ -700,15 +697,15 @@ pub fn builtin_unexpected_argument(
 
 /// Print the backtrace and call for help that we use at the end of error messages.
 pub fn builtin_print_error_trailer(parser: &Parser, b: &mut OutputStream, cmd: &wstr) {
-    b.push('\n');
+    b.append_char('\n');
     let stacktrace = parser.current_line();
     // Don't print two empty lines if we don't have a stacktrace.
     if !stacktrace.is_empty() {
-        b.append(stacktrace);
-        b.push('\n');
+        b.append(&stacktrace);
+        b.append_char('\n');
     }
-    b.append(wgettext_fmt!(
-        "(Type 'help %ls' for related documentation)\n",
+    b.append(&wgettext_fmt!(
+        "(Type 'help %s' for related documentation)\n",
         cmd
     ));
 }
@@ -721,8 +718,8 @@ pub fn builtin_wperror(program_name: &wstr, streams: &mut IoStreams) {
     streams.err.append(L!(": "));
     if err.0 != 0 {
         let werr = WString::from_str(&err.to_string());
-        streams.err.append(werr);
-        streams.err.push('\n');
+        streams.err.append(&werr);
+        streams.err.append_char('\n');
     }
 }
 
@@ -740,8 +737,8 @@ impl HelpOnlyCmdOpts {
         let cmd = args[0];
         let print_hints = true;
 
-        const shortopts: &wstr = L!("+h");
-        const longopts: &[WOption] = &[wopt(L!("help"), ArgType::NoArgument, 'h')];
+        let shortopts: &wstr = L!("+h");
+        let longopts: &[WOption] = &[wopt(L!("help"), ArgType::NoArgument, 'h')];
 
         let mut print_help = false;
         let mut w = WGetopter::new(shortopts, longopts, args);
@@ -804,6 +801,17 @@ pub enum SplitBehavior {
     Never,
 }
 
+pub struct InputValue<'args> {
+    pub arg: Cow<'args, wstr>,
+    pub want_newline: bool,
+}
+
+impl<'args> InputValue<'args> {
+    pub fn new(arg: Cow<'args, wstr>, want_newline: bool) -> Self {
+        Self { arg, want_newline }
+    }
+}
+
 /// A helper type for extracting arguments from either argv or stdin.
 pub struct Arguments<'args, 'iter> {
     /// The list of arguments passed to the string builtin.
@@ -856,7 +864,7 @@ impl<'args, 'iter> Arguments<'args, 'iter> {
         self
     }
 
-    fn get_arg_stdin(&mut self) -> Option<(Cow<'args, wstr>, bool)> {
+    fn get_arg_stdin(&mut self) -> Option<InputValue<'args>> {
         use SplitBehavior::*;
         let reader = self.reader.as_mut().unwrap();
 
@@ -901,11 +909,10 @@ impl<'args, 'iter> Arguments<'args, 'iter> {
             _ => unreachable!(),
         };
 
-        let parsed = str2wcstring(&self.buffer[..end]);
-
-        let retval = Some((Cow::Owned(parsed), want_newline));
+        let parsed = bytes2wcstring(&self.buffer[..end]);
         self.buffer.clear();
-        retval
+
+        Some(InputValue::new(Cow::Owned(parsed), want_newline))
     }
 }
 
@@ -915,7 +922,7 @@ impl<'args> Iterator for Arguments<'args, '_> {
     // This is an edge case -- we expect text input, which is conventionally terminated by a
     // newline character. But if it isn't, we use this to avoid creating one out of thin air,
     // to not corrupt input data.
-    type Item = (Cow<'args, wstr>, bool);
+    type Item = InputValue<'args>;
 
     fn next(&mut self) -> Option<Self::Item> {
         if self.reader.is_some() {
@@ -925,9 +932,47 @@ impl<'args> Iterator for Arguments<'args, '_> {
         if *self.argidx >= self.args.len() {
             return None;
         }
-        let retval = (Cow::Borrowed(self.args[*self.argidx]), true);
+        let retval = InputValue::new(
+            Cow::Borrowed(self.args[*self.argidx]),
+            /*want_newline=*/ true,
+        );
         *self.argidx += 1;
-        return Some(retval);
+        Some(retval)
+    }
+}
+
+pub fn parse_pid(streams: &mut IoStreams, cmd: &wstr, arg: &wstr) -> Result<Pid, ErrorCode> {
+    parsed_pid(streams, cmd, arg, fish_wcstoi(arg))
+}
+
+pub fn parse_pid_may_be_zero(
+    streams: &mut IoStreams,
+    cmd: &wstr,
+    arg: &wstr,
+) -> Result<Option<Pid>, ErrorCode> {
+    let parsed = fish_wcstoi(arg);
+    if parsed == Ok(0) {
+        return Ok(None);
+    }
+    parsed_pid(streams, cmd, arg, parsed).map(Some)
+}
+
+fn parsed_pid(
+    streams: &mut IoStreams,
+    cmd: &wstr,
+    arg: &wstr,
+    pid: Result<i32, wutil::Error>,
+) -> Result<Pid, ErrorCode> {
+    match pid {
+        Ok(pid @ 1..) => Ok(Pid::new(pid)),
+        _ => {
+            streams.err.append(&wgettext_fmt!(
+                "%s: '%s' is not a valid process ID\n",
+                cmd,
+                arg
+            ));
+            Err(STATUS_INVALID_ARGS)
+        }
     }
 }
 
@@ -954,7 +999,7 @@ fn builtin_generic(parser: &Parser, streams: &mut IoStreams, argv: &mut [&wstr])
 
 /// This function handles both the 'continue' and the 'break' builtins that are used for loop
 /// control.
-fn builtin_break_continue(
+pub fn builtin_break_continue(
     parser: &Parser,
     streams: &mut IoStreams,
     argv: &mut [&wstr],
@@ -972,7 +1017,7 @@ fn builtin_break_continue(
     if argc != 1 {
         streams
             .err
-            .append(wgettext_fmt!(BUILTIN_ERR_UNKNOWN, argv[0], argv[1]));
+            .append(&wgettext_fmt!(BUILTIN_ERR_UNKNOWN, argv[0], argv[1]));
         return Err(STATUS_INVALID_ARGS);
     }
 
@@ -991,7 +1036,7 @@ fn builtin_break_continue(
     if !has_loop {
         streams
             .err
-            .append(wgettext_fmt!("%ls: Not inside of loop\n", argv[0]));
+            .append(&wgettext_fmt!("%s: Not inside of loop\n", argv[0]));
         return Err(STATUS_CMD_ERROR);
     }
 
@@ -1003,68 +1048,3 @@ fn builtin_break_continue(
     };
     Ok(SUCCESS)
 }
-
-/// Implementation of the builtin breakpoint command, used to launch the interactive debugger.
-fn builtin_breakpoint(
-    parser: &Parser,
-    streams: &mut IoStreams,
-    argv: &mut [&wstr],
-) -> BuiltinResult {
-    let cmd = argv[0];
-    if argv.len() != 1 {
-        streams.err.append(wgettext_fmt!(
-            BUILTIN_ERR_ARG_COUNT1,
-            cmd,
-            0,
-            argv.len() - 1
-        ));
-        return Err(STATUS_INVALID_ARGS);
-    }
-
-    // If we're not interactive then we can't enter the debugger. So treat this command as a no-op.
-    if !parser.is_interactive() {
-        return Err(STATUS_CMD_ERROR);
-    }
-
-    // Ensure we don't allow creating a breakpoint at an interactive prompt. There may be a simpler
-    // or clearer way to do this but this works.
-    {
-        if parser
-            .block_at_index(1)
-            .map_or(true, |b| b.typ() == BlockType::breakpoint)
-        {
-            streams.err.append(wgettext_fmt!(
-                "%ls: Command not valid at an interactive prompt\n",
-                cmd,
-            ));
-            return Err(STATUS_ILLEGAL_CMD);
-        }
-    }
-
-    let bpb = parser.push_block(Block::breakpoint_block());
-    let io_chain = &streams.io_chain;
-    reader_read(parser, STDIN_FILENO, io_chain)?;
-    parser.pop_block(bpb);
-    BuiltinResult::from_dynamic(parser.get_last_status())
-}
-
-fn builtin_true(_parser: &Parser, _streams: &mut IoStreams, _argv: &mut [&wstr]) -> BuiltinResult {
-    Ok(SUCCESS)
-}
-
-fn builtin_false(_parser: &Parser, _streams: &mut IoStreams, _argv: &mut [&wstr]) -> BuiltinResult {
-    Err(STATUS_CMD_ERROR)
-}
-
-/// Used for the fish `_` builtin for requesting translations.
-/// For scripts in `share/`, the corresponding strings are extracted from the scripts using
-/// `build_tools/fish_xgettext.fish`.
-/// Strings not present in our repo would require a custom MO file for translation to be possible.
-fn builtin_gettext(_parser: &Parser, streams: &mut IoStreams, argv: &mut [&wstr]) -> BuiltinResult {
-    for arg in &argv[1..] {
-        streams.out.append(
-            crate::wutil::LocalizableString::from_external_source((*arg).to_owned()).localize(),
-        );
-    }
-    Ok(SUCCESS)
-}
