@@ -4,19 +4,21 @@ use crate::expand::{
     BRACE_BEGIN, BRACE_END, BRACE_SEP, BRACE_SPACE, HOME_DIRECTORY, INTERNAL_SEPARATOR,
     PROCESS_EXPAND_SELF, PROCESS_EXPAND_SELF_STR, VARIABLE_EXPAND, VARIABLE_EXPAND_SINGLE,
 };
-use crate::fallback::fish_wcwidth;
 use crate::future_feature_flags::{FeatureFlag, feature_test};
 use crate::global_safety::AtomicRef;
 use crate::global_safety::RelaxedAtomicBool;
 use crate::key;
 use crate::parse_util::parse_util_escape_string_with_quote;
+use crate::prelude::*;
 use crate::terminal::Output;
 use crate::termsize::Termsize;
-use crate::wchar::{decode_byte_from_char, encode_byte_to_char, prelude::*};
-use crate::wcstringutil::wcs2bytes_callback;
+use crate::wcstringutil::str2bytes_callback;
 use crate::wildcard::{ANY_CHAR, ANY_STRING, ANY_STRING_RECURSIVE};
 use crate::wutil::fish_iswalnum;
 use bitflags::bitflags;
+use fish_common::{ENCODE_DIRECT_END, char_offset, is_console_session, subslice_position};
+use fish_fallback::fish_wcwidth;
+use fish_wchar::{decode_byte_from_char, encode_byte_to_char};
 use libc::{SIG_IGN, SIGTTOU, STDIN_FILENO};
 use once_cell::sync::OnceCell;
 use std::cell::{Cell, RefCell};
@@ -61,21 +63,6 @@ pub const WILDCARD_RESERVED_END: char = char_offset(WILDCARD_RESERVED_BASE, 16);
 // Unicode range for our needs.
 const _: () = assert!(WILDCARD_RESERVED_END <= RESERVED_CHAR_END);
 
-// These are in the Unicode private-use range. We really shouldn't use this
-// range but have little choice in the matter given how our lexer/parser works.
-// We can't use non-characters for these two ranges because there are only 66 of
-// them and we need at least 256 + 64.
-//
-// If sizeof(wchar_t))==4 we could avoid using private-use chars; however, that
-// would result in fish having different behavior on machines with 16 versus 32
-// bit wchar_t. It's better that fish behave the same on both types of systems.
-//
-// Note: We don't use the highest 8 bit range (0xF800 - 0xF8FF) because we know
-// of at least one use of a codepoint in that range: the Apple symbol (0xF8FF)
-// on Mac OS X. See http://www.unicode.org/faq/private_use.html.
-pub const ENCODE_DIRECT_BASE: char = '\u{F600}';
-pub const ENCODE_DIRECT_END: char = char_offset(ENCODE_DIRECT_BASE, 256);
-
 #[derive(Debug, Clone, Copy, PartialEq, Eq)]
 pub enum EscapeStringStyle {
     Script(EscapeFlags),
@@ -184,7 +171,7 @@ fn escape_string_script(input: &wstr, flags: EscapeFlags) -> WString {
     let escape_comma = flags.contains(EscapeFlags::COMMA);
     let no_quoted = flags.contains(EscapeFlags::NO_QUOTED);
     let no_tilde = flags.contains(EscapeFlags::NO_TILDE);
-    let no_qmark = feature_test(FeatureFlag::qmark_noglob);
+    let no_qmark = feature_test(FeatureFlag::QuestionMarkNoGlob);
     let symbolic = flags.contains(EscapeFlags::SYMBOLIC);
 
     assert!(
@@ -501,7 +488,7 @@ fn unescape_string_internal(input: &wstr, flags: UnescapeFlags) -> Option<WStrin
     let unescape_special = flags.contains(UnescapeFlags::SPECIAL);
     let allow_incomplete = flags.contains(UnescapeFlags::INCOMPLETE);
     let ignore_backslashes = flags.contains(UnescapeFlags::NO_BACKSLASHES);
-    let allow_percent_self = !feature_test(FeatureFlag::remove_percent_self);
+    let allow_percent_self = !feature_test(FeatureFlag::RemovePercentSelf);
 
     // The positions of open braces.
     let mut braces = vec![];
@@ -583,7 +570,7 @@ fn unescape_string_internal(input: &wstr, flags: UnescapeFlags) -> Option<WStrin
                     }
                 }
                 '?' => {
-                    if unescape_special && !feature_test(FeatureFlag::qmark_noglob) {
+                    if unescape_special && !feature_test(FeatureFlag::QuestionMarkNoGlob) {
                         to_append_or_none = Some(ANY_CHAR);
                     }
                 }
@@ -620,7 +607,7 @@ fn unescape_string_internal(input: &wstr, flags: UnescapeFlags) -> Option<WStrin
                             // HACK: To reduce accidental use of brace expansion, treat a brace
                             // with zero or one items as literal input. See #4632. (The hack is
                             // doing it here and like this.)
-                            if vars_or_seps.last().map(|i| *i < brace).unwrap_or(true) {
+                            if vars_or_seps.last().is_none_or(|i| *i < brace) {
                                 result.as_char_slice_mut()[brace] = '{';
                                 // We also need to turn all spaces back.
                                 for i in brace + 1..result.len() {
@@ -1016,13 +1003,6 @@ pub fn read_unquoted_escape(
     Some(in_pos)
 }
 
-pub const fn char_offset(base: char, offset: u32) -> char {
-    match char::from_u32(base as u32 + offset) {
-        Some(c) => c,
-        None => panic!("not a valid char"),
-    }
-}
-
 /// Exits without invoking destructors (via _exit), useful for code after fork.
 pub fn exit_without_destructors(code: libc::c_int) -> ! {
     unsafe { libc::_exit(code) };
@@ -1044,11 +1024,11 @@ pub fn get_ellipsis_str() -> &'static wstr {
 }
 
 /// Character representing an omitted newline at the end of text.
-pub fn get_omitted_newline_str() -> &'static wstr {
+pub fn get_omitted_newline_str() -> &'static str {
     OMITTED_NEWLINE_STR.load()
 }
 
-static OMITTED_NEWLINE_STR: AtomicRef<wstr> = AtomicRef::new(&L!(""));
+static OMITTED_NEWLINE_STR: AtomicRef<str> = AtomicRef::new(&"");
 
 pub fn get_omitted_newline_width() -> usize {
     OMITTED_NEWLINE_STR.load().len()
@@ -1171,11 +1151,7 @@ pub(crate) fn charptr2wcstring(input: *const libc::c_char) -> WString {
 ///
 /// This function decodes illegal character sequences in a reversible way using the private use
 /// area.
-pub fn wcs2bytes(input: &wstr) -> Vec<u8> {
-    if input.is_empty() {
-        return vec![];
-    }
-
+pub fn wcs2bytes(input: impl IntoCharIter) -> Vec<u8> {
     let mut result = vec![];
     wcs2bytes_appending(&mut result, input);
     result
@@ -1199,7 +1175,7 @@ pub fn wcs2zstring(input: &wstr) -> CString {
     }
 
     let mut vec = Vec::with_capacity(input.len() + 1);
-    wcs2bytes_callback(input, |buff| {
+    str2bytes_callback(input, |buff| {
         vec.extend_from_slice(buff);
         true
     });
@@ -1219,9 +1195,8 @@ pub fn wcs2zstring(input: &wstr) -> CString {
 }
 
 /// Like [`wcs2bytes`], but appends to `output` instead of returning a new string.
-pub fn wcs2bytes_appending(output: &mut Vec<u8>, input: &wstr) {
-    output.reserve(input.len());
-    wcs2bytes_callback(input, |buff| {
+pub fn wcs2bytes_appending(output: &mut Vec<u8>, input: impl IntoCharIter) {
+    str2bytes_callback(input, |buff| {
         output.extend_from_slice(buff);
         true
     });
@@ -1231,25 +1206,16 @@ pub fn wcs2bytes_appending(output: &mut Vec<u8>, input: &wstr) {
 pub type FilenameRef = Arc<WString>;
 
 pub fn init_special_chars_once() {
-    // Helper to make a static reference to a static &'wstr, from a string literal.
-    // This is necessary to store them in global atomics, as these can't handle fat pointers.
-    macro_rules! LL {
-        ($s:literal) => {{
-            const S: &'static wstr = L!($s);
-            &S
-        }};
-    }
-
     if is_windows_subsystem_for_linux(WSL::Any) {
         // neither of \u23CE and \u25CF can be displayed in the default fonts on Windows, though
         // they can be *encoded* just fine. Use alternative glyphs.
-        OMITTED_NEWLINE_STR.store(LL!("\u{00b6}")); // "pilcrow"
+        OMITTED_NEWLINE_STR.store(&"\u{00b6}"); // "pilcrow"
         OBFUSCATION_READ_CHAR.store(u32::from('\u{2022}'), Ordering::Relaxed); // "bullet" (•)
     } else if is_console_session() {
-        OMITTED_NEWLINE_STR.store(LL!("^J"));
+        OMITTED_NEWLINE_STR.store(&"^J");
         OBFUSCATION_READ_CHAR.store(u32::from('*'), Ordering::Relaxed);
     } else {
-        OMITTED_NEWLINE_STR.store(LL!("\u{23CE}")); // "return symbol" (⏎)
+        OMITTED_NEWLINE_STR.store(&"\u{23CE}"); // "return symbol" (⏎)
         OBFUSCATION_READ_CHAR.store(
             u32::from(
                 '\u{25CF}', // "black circle" (●)
@@ -1335,6 +1301,42 @@ macro_rules! write_to_output {
     }};
 }
 
+pub const fn help_section_exists(section: &str) -> bool {
+    let haystack = include_str!("../share/help_sections");
+    let needle = section;
+
+    let needle = needle.as_bytes();
+    let haystack = haystack.as_bytes();
+    let nlen = needle.len();
+    let mut line_start = 0;
+    let mut i = 0;
+    while i <= haystack.len() {
+        if i == haystack.len() || haystack[i] == b'\n' {
+            let line_len = i - line_start;
+
+            if line_len == nlen {
+                let mut j = 0;
+                while j < nlen && haystack[line_start + j] == needle[j] {
+                    j += 1;
+                }
+                if j == nlen {
+                    return true;
+                }
+            }
+            line_start = i + 1;
+        }
+        i += 1;
+    }
+    false
+}
+
+macro_rules! help_section {
+    ($section:expr) => {{
+        const _: () = assert!(crate::common::help_section_exists($section));
+        $section
+    }};
+}
+
 /// Write the given paragraph of output, redoing linebreaks to fit `termsize`.
 pub fn reformat_for_screen(msg: &wstr, termsize: &Termsize) -> WString {
     let mut buff = WString::new();
@@ -1441,13 +1443,6 @@ fn slice_contains_slice<T: Eq>(a: &[T], b: &[T]) -> bool {
     subslice_position(a, b).is_some()
 }
 
-pub fn subslice_position<T: Eq>(a: &[T], b: &[T]) -> Option<usize> {
-    if b.is_empty() {
-        return Some(0);
-    }
-    a.windows(b.len()).position(|aw| aw == b)
-}
-
 #[derive(Copy, Debug, Clone, PartialEq, Eq)]
 pub enum WSL {
     Any,
@@ -1531,9 +1526,9 @@ pub fn is_windows_subsystem_for_linux(v: WSL) -> bool {
         // this check: if the environment variable FISH_NO_WSL_CHECK is present, this test
         // is bypassed. We intentionally do not include this in the error message because
         // it'll only allow fish to run but not to actually work. Here be dragons!
-        use crate::flog::FLOG;
+        use crate::flog::flog;
         if env::var_os("FISH_NO_WSL_CHECK").is_none() {
-            FLOG!(
+            flog!(
                 error,
                 concat!(
                     "This version of WSL has known bugs that prevent fish from working.\n",
@@ -1796,39 +1791,6 @@ impl<T, F: FnOnce(T)> ScopeGuarding for ScopeGuard<T, F> {}
 pub const fn assert_send<T: Send>() {}
 pub const fn assert_sync<T: Sync>() {}
 
-/// This function attempts to distinguish between a console session (at the actual login vty) and a
-/// session within a terminal emulator inside a desktop environment or over SSH. Unfortunately
-/// there are few values of $TERM that we can interpret as being exclusively console sessions, and
-/// most common operating systems do not use them. The value is cached for the duration of the fish
-/// session. We err on the side of assuming it's not a console session. This approach isn't
-/// bullet-proof and that's OK.
-pub fn is_console_session() -> bool {
-    static IS_CONSOLE_SESSION: OnceCell<bool> = OnceCell::new();
-    *IS_CONSOLE_SESSION.get_or_init(|| {
-        const PATH_MAX: usize = libc::PATH_MAX as usize;
-        let mut tty_name = [0u8; PATH_MAX];
-        unsafe {
-            if libc::ttyname_r(STDIN_FILENO, tty_name.as_mut_ptr().cast(), tty_name.len()) != 0 {
-                return false;
-            }
-        }
-        // Check if the tty matches /dev/(console|dcons|tty[uv\d])
-        const LEN: usize = b"/dev/tty".len();
-        (
-        (
-            tty_name.starts_with(b"/dev/tty") &&
-                ([b'u', b'v'].contains(&tty_name[LEN]) || tty_name[LEN].is_ascii_digit())
-        ) ||
-        tty_name.starts_with(b"/dev/dcons\0") ||
-        tty_name.starts_with(b"/dev/console\0"))
-        // and that $TERM is simple, e.g. `xterm` or `vt100`, not `xterm-something` or `sun-color`.
-        && match env::var_os("TERM") {
-            Some(term) => !term.as_bytes().contains(&b'-'),
-            None => true,
-        }
-    })
-}
-
 /// Asserts that a slice is alphabetically sorted by a <code>&[wstr]</code> `name` field.
 ///
 /// Mainly useful for static asserts/const eval.
@@ -1840,7 +1802,7 @@ pub fn is_console_session() -> bool {
 /// # Examples
 ///
 /// ```
-/// use fish::wchar::prelude::*;
+/// use fish::prelude::*;
 /// use fish::assert_sorted_by_name;
 ///
 /// const COLORS: &[(&wstr, u32)] = &[
@@ -1856,7 +1818,7 @@ pub fn is_console_session() -> bool {
 /// While this example would fail to compile:
 ///
 /// ```compile_fail
-/// use fish::wchar::prelude::*;
+/// use fish::prelude::*;
 /// use fish::assert_sorted_by_name;
 ///
 /// const COLORS: &[(&wstr, u32)] = &[
@@ -2002,13 +1964,15 @@ pub const ESCAPE_TEST_CHAR: usize = 4000;
 
 #[cfg(test)]
 mod tests {
+
     use super::{
-        ENCODE_DIRECT_BASE, ENCODE_DIRECT_END, ESCAPE_TEST_CHAR, EscapeFlags, EscapeStringStyle,
-        ScopeGuard, ScopedCell, ScopedRefCell, UnescapeStringStyle, bytes2wcstring, escape_string,
+        ENCODE_DIRECT_END, ESCAPE_TEST_CHAR, EscapeFlags, EscapeStringStyle, ScopeGuard,
+        ScopedCell, ScopedRefCell, UnescapeStringStyle, bytes2wcstring, escape_string,
         truncate_at_nul, unescape_string, wcs2bytes,
     };
-    use crate::util::{get_rng_seed, get_seeded_rng};
-    use crate::wchar::{L, WString, wstr};
+    use crate::util::get_seeded_rng;
+    use fish_common::ENCODE_DIRECT_BASE;
+    use fish_wchar::{L, WString, wstr};
     use rand::{Rng, RngCore};
 
     #[test]
@@ -2081,14 +2045,14 @@ mod tests {
     }
 
     fn escape_test(escape_style: EscapeStringStyle, unescape_style: UnescapeStringStyle) {
-        let seed: u128 = 92348567983274852905629743984572;
+        let seed = rand::rng().next_u64();
         let mut rng = get_seeded_rng(seed);
 
         let mut random_string = WString::new();
         let mut escaped_string;
         for _ in 0..(ESCAPE_TEST_COUNT as u32) {
             random_string.clear();
-            let length = rng.gen_range(0..=(2 * ESCAPE_TEST_LENGTH));
+            let length = rng.random_range(0..=(2 * ESCAPE_TEST_LENGTH));
             for _ in 0..length {
                 random_string
                     .push(char::from_u32((rng.next_u32() % ESCAPE_TEST_CHAR as u32) + 1).unwrap());
@@ -2097,11 +2061,13 @@ mod tests {
             escaped_string = escape_string(&random_string, escape_style);
             let Some(unescaped_string) = unescape_string(&escaped_string, unescape_style) else {
                 let slice = escaped_string.as_char_slice();
-                panic!("Failed to unescape string {slice:?}");
+                panic!("Failed to unescape string {slice:?}. Generated from seed {seed}.");
             };
             assert_eq!(
                 random_string, unescaped_string,
-                "Escaped and then unescaped string {random_string:?}, but got back a different string {unescaped_string:?}. The intermediate escape looked like {escaped_string:?}."
+                "Escaped and then unescaped string {random_string:?}, but got back a different string {unescaped_string:?}. \
+                The intermediate escape looked like {escaped_string:?}. \
+                Generated from seed {seed}."
             );
         }
     }
@@ -2159,12 +2125,12 @@ mod tests {
     /// string comes back through double conversion.
     #[test]
     fn test_convert() {
-        let seed = get_rng_seed();
+        let seed = rand::rng().next_u64();
         let mut rng = get_seeded_rng(seed);
         let mut origin = Vec::new();
 
         for _ in 0..ESCAPE_TEST_COUNT {
-            let length: usize = rng.gen_range(0..=(2 * ESCAPE_TEST_LENGTH));
+            let length: usize = rng.random_range(0..=(2 * ESCAPE_TEST_LENGTH));
             origin.resize(length, 0);
             rng.fill_bytes(&mut origin);
 
