@@ -1,5 +1,5 @@
 use crate::common::{BUILD_DIR, get_program_name};
-use crate::{FLOG, FLOGF};
+use crate::{flog, flogf};
 use fish_build_helper::workspace_root;
 use once_cell::sync::OnceCell;
 use std::ffi::OsStr;
@@ -9,22 +9,20 @@ use std::path::{Path, PathBuf};
 /// A struct of configuration directories, determined in main() that fish will optionally pass to
 /// env_init.
 pub struct ConfigPaths {
-    pub sysconf: PathBuf,     // e.g., /usr/local/etc
-    pub bin: Option<PathBuf>, // e.g., /usr/local/bin
-    /// Always present if "embed-data" is disabled.
+    pub sysconf: PathBuf,      // e.g., /usr/local/etc
+    pub bin: Option<PathBuf>,  // e.g., /usr/local/bin
     pub data: Option<PathBuf>, // e.g., /usr/local/share
-    /// Always present if "embed-data" is disabled.
-    pub doc: Option<PathBuf>, // e.g., /usr/local/share/doc/fish
+    pub man: Option<PathBuf>,  // e.g., /usr/local/share/fish/man
+    pub doc: Option<PathBuf>,  // e.g., /usr/local/share/doc/fish
 }
 
 const SYSCONF_DIR: &str = env!("SYSCONFDIR");
-const DOC_DIR: Option<&str> = option_env!("DOCDIR");
 
 impl ConfigPaths {
     pub fn new() -> Self {
         FISH_PATH.get_or_init(compute_fish_path);
         let exec_path = get_fish_path();
-        FLOG!(
+        flog!(
             config,
             match exec_path {
                 FishPath::Absolute(path) => format!("executable path: {}", path.display()),
@@ -32,14 +30,14 @@ impl ConfigPaths {
             }
         );
         let paths = Self::from_exec_path(exec_path);
-        FLOGF!(
+        flogf!(
             config,
             "paths.sysconf: %s",
             paths.sysconf.display().to_string()
         );
         macro_rules! log_optional_path {
             ($field:ident) => {
-                FLOGF!(
+                flogf!(
                     config,
                     "paths.%s: %s",
                     stringify!($field),
@@ -53,19 +51,24 @@ impl ConfigPaths {
         }
         log_optional_path!(bin);
         log_optional_path!(data);
+        log_optional_path!(man);
         log_optional_path!(doc);
         paths
     }
 
     fn from_exec_path(unresolved_exec_path: &'static FishPath) -> Self {
-        let default_layout = |exec_path_parent: Option<&Path>| Self {
-            sysconf: PathBuf::from(SYSCONF_DIR).join("fish"),
-            bin: option_env!("BINDIR")
-                .map(PathBuf::from)
-                // N.B. the argument may be non-canonical here.
-                .or_else(|| exec_path_parent.map(|p| p.to_owned())),
-            data: option_env!("DATADIR").map(|p| PathBuf::from(p).join("fish")),
-            doc: DOC_DIR.map(PathBuf::from),
+        let default_layout = |exec_path_parent: Option<&Path>| {
+            let data = option_env!("DATADIR").map(|p| PathBuf::from(p).join("fish"));
+            Self {
+                sysconf: PathBuf::from(SYSCONF_DIR).join("fish"),
+                bin: option_env!("BINDIR")
+                    .map(PathBuf::from)
+                    // N.B. the argument may be non-canonical here.
+                    .or_else(|| exec_path_parent.map(|p| p.to_owned())),
+                data: data.clone(),
+                man: data.map(|data| data.join("man")),
+                doc: option_env!("DOCDIR").map(PathBuf::from),
+            }
         };
 
         let exec_path = {
@@ -73,7 +76,7 @@ impl ConfigPaths {
             match unresolved_exec_path {
                 Absolute(p) => {
                     let Ok(exec_path) = p.canonicalize() else {
-                        FLOG!(
+                        flog!(
                             config,
                             format!(
                                 "Failed to canonicalize executable path '{}'. Using default paths",
@@ -85,7 +88,7 @@ impl ConfigPaths {
                     exec_path
                 }
                 LookUpInPath => {
-                    FLOG!(
+                    flog!(
                         config,
                         "No absolute executable path available. Using default paths",
                     );
@@ -95,7 +98,7 @@ impl ConfigPaths {
         };
 
         let Some(exec_path_parent) = exec_path.parent() else {
-            FLOG!(
+            flog!(
                 config,
                 "Executable path reported to be the root directory?! Using default paths.",
             );
@@ -104,7 +107,7 @@ impl ConfigPaths {
 
         let workspace_root = workspace_root();
         // TODO(MSRV>=1.88): if-let-chain
-        if exec_path_parent.ends_with("bin") && {
+        if cfg!(using_cmake) && exec_path_parent.ends_with("bin") && {
             let prefix = exec_path_parent.parent().unwrap();
             let data = prefix.join("share/fish");
             let sysconf = prefix.join("etc/fish");
@@ -114,38 +117,39 @@ impl ConfigPaths {
             // Installing somewhere else inside the workspace is fine.
             && prefix != workspace_root
         } {
-            FLOG!(config, "Running from relocatable tree");
+            flog!(config, "Running from relocatable tree");
             let prefix = exec_path_parent.parent().unwrap();
+            let data = prefix.join("share/fish");
             Self {
                 sysconf: prefix.join("etc/fish"),
                 bin: Some(exec_path_parent.to_owned()),
-                data: Some(prefix.join("share/fish")),
-                doc: {
-                    let doc = prefix.join("share/doc/fish");
-                    if doc.exists() {
-                        Some(doc)
-                    } else {
-                        DOC_DIR.map(PathBuf::from)
-                    }
-                },
+                data: Some(data.clone()),
+                man: Some(data.join("man")),
+                doc: Some(prefix.join("share/doc/fish")),
             }
         } else if exec_path.starts_with(BUILD_DIR) {
-            FLOG!(
+            flog!(
                 config,
                 format!(
                     "Running out of build directory, using paths relative to $CARGO_MANIFEST_DIR ({})",
                     workspace_root.display()
                 ),
             );
+            let user_doc_join = |dir| {
+                cfg!(using_cmake)
+                    .then_some(Path::new(BUILD_DIR))
+                    .map(|path| path.join("user_doc").join(dir))
+            };
             // If we're in Cargo's target directory or in CMake's build directory, use the source files.
             Self {
                 sysconf: workspace_root.join("etc"),
                 bin: Some(exec_path_parent.to_owned()),
                 data: Some(workspace_root.join("share")),
-                doc: Some(workspace_root.join("user_doc/html")),
+                man: user_doc_join("man"),
+                doc: user_doc_join("html"),
             }
         } else {
-            FLOG!(
+            flog!(
                 config,
                 "Not in a relocatable tree or build directory, using default paths"
             );
