@@ -10,21 +10,22 @@ use crate::env::config_paths::ConfigPaths;
 use crate::env::{EnvMode, EnvVar, Statuses};
 use crate::env_dispatch::{env_dispatch_init, env_dispatch_var_change};
 use crate::event::Event;
-use crate::flog::FLOG;
+use crate::flog::flog;
 use crate::global_safety::RelaxedAtomicBool;
 use crate::input::{FISH_BIND_MODE_VAR, init_input};
+use crate::localization::wgettext;
 use crate::nix::{geteuid, getpid};
 use crate::null_terminated_array::OwningNullTerminatedArray;
 use crate::path::{
     path_emit_config_directory_messages, path_get_cache, path_get_config, path_get_data,
     path_make_canonical, paths_are_same_file,
 };
+use crate::prelude::*;
 use crate::proc::is_interactive_session;
 use crate::termsize;
 use crate::universal_notifier::default_notifier;
-use crate::wchar::prelude::*;
 use crate::wcstringutil::join_strings;
-use crate::wutil::{fish_wcstol, wgetcwd, wgettext};
+use crate::wutil::{fish_wcstol, wgetcwd};
 
 use libc::{c_int, uid_t};
 use once_cell::sync::{Lazy, OnceCell};
@@ -261,7 +262,7 @@ impl EnvStack {
     pub fn set_pwd_from_getcwd(&self) {
         let cwd = wgetcwd();
         if cwd.is_empty() {
-            FLOG!(
+            flog!(
                 error,
                 wgettext!(
                     "Could not determine current working directory. Is your locale set correctly?"
@@ -418,6 +419,7 @@ impl Environment for EnvStack {
 const FISH_DATADIR_VAR: &wstr = L!("__fish_data_dir");
 const FISH_SYSCONFDIR_VAR: &wstr = L!("__fish_sysconf_dir");
 const FISH_HELPDIR_VAR: &wstr = L!("__fish_help_dir");
+const FISH_MANDIR_VAR: &wstr = L!("__fish_man_dir");
 const FISH_BIN_DIR: &wstr = L!("__fish_bin_dir");
 const FISH_CONFIG_DIR: &wstr = L!("__fish_config_dir");
 const FISH_USER_DATA_DIR: &wstr = L!("__fish_user_data_dir");
@@ -646,13 +648,8 @@ pub fn env_init(paths: Option<&ConfigPaths>, do_uvars: bool, default_paths: bool
         set_path(FISH_SYSCONFDIR_VAR, Some(&paths.sysconf));
         set_path(FISH_BIN_DIR, paths.bin.as_ref());
 
-        let datadir = paths.data.as_ref();
-        set_path(FISH_DATADIR_VAR, datadir);
-        if !cfg!(feature = "embed-data") && default_paths {
-            let mut scstr = datadir.unwrap().clone();
-            scstr.push("functions");
-            set_path(L!("fish_function_path"), Some(&scstr));
-        }
+        set_path(FISH_DATADIR_VAR, paths.data.as_ref());
+        set_path(FISH_MANDIR_VAR, paths.man.as_ref());
         set_path(FISH_HELPDIR_VAR, paths.doc.as_ref());
     }
 
@@ -832,8 +829,8 @@ pub fn env_init(paths: Option<&ConfigPaths>, do_uvars: bool, default_paths: bool
 #[cfg(test)]
 mod tests {
     use super::{EnvMode, EnvStack, Environment};
+    use crate::prelude::*;
     use crate::tests::prelude::*;
-    use crate::wchar::prelude::*;
 
     #[test]
     #[serial]
