@@ -4,15 +4,15 @@ use crate::env::{
     PATH_ARRAY_SEP, Statuses, VarTable, is_read_only,
 };
 use crate::env_universal_common::EnvUniversal;
-use crate::flog::FLOG;
+use crate::flog::flog;
 use crate::global_safety::RelaxedAtomicBool;
 use crate::history::{History, history_session_id_from_var};
 use crate::kill::kill_entries;
 use crate::nix::umask;
 use crate::null_terminated_array::OwningNullTerminatedArray;
+use crate::prelude::*;
 use crate::reader::{commandline_get_state, reader_status_count};
 use crate::threads::{is_forked_child, is_main_thread};
-use crate::wchar::prelude::*;
 use crate::wutil::fish_wcstol_radix;
 
 use once_cell::sync::Lazy;
@@ -371,10 +371,10 @@ impl EnvScopedImpl {
                 let session_id = history_session_id_from_var(fish_history_var);
                 History::with_name(&session_id)
             });
-            return Some(EnvVar::new_from_name_vec(
+            Some(EnvVar::new_from_name_vec(
                 L!("history"),
                 history.get_history(),
-            ));
+            ))
         } else if key == "fish_killring" {
             Some(EnvVar::new_from_name_vec(
                 L!("fish_killring"),
@@ -593,7 +593,7 @@ impl EnvScopedImpl {
         if cursor.next().is_some() {
             mismatch = true;
         }
-        return mismatch;
+        mismatch
     }
 
     /// Get the exported variables into a variable table.
@@ -619,7 +619,7 @@ impl EnvScopedImpl {
 
     /// Return a newly allocated export array.
     fn create_export_array(&self) -> Arc<OwningNullTerminatedArray> {
-        FLOG!(env_export, "create_export_array() recalc");
+        flog!(env_export, "create_export_array() recalc");
         let mut vals = VarTable::new();
         Self::get_exported(&self.globals, &mut vals);
         Self::get_exported(&self.locals, &mut vals);
@@ -646,7 +646,7 @@ impl EnvScopedImpl {
             str.push_utfstr(&val.as_string());
             export_list.push(wcs2zstring(&str));
         }
-        return Arc::new(OwningNullTerminatedArray::new(export_list));
+        Arc::new(OwningNullTerminatedArray::new(export_list))
     }
 
     // Exported variable array used by execv.
@@ -660,7 +660,7 @@ impl EnvScopedImpl {
             self.enumerate_generations(|r#gen| generations.push(r#gen));
             self.export_array_generations = generations;
         }
-        return self.export_array.as_ref().unwrap().clone();
+        self.export_array.as_ref().unwrap().clone()
     }
 }
 
@@ -986,7 +986,7 @@ impl EnvStackImpl {
             pathvar: Some(false),
         };
         Self::set_in_node(&mut self.base.globals, key, val, flags);
-        return Some(EnvStackSetResult::Ok);
+        Some(EnvStackSetResult::Ok)
     }
 
     /// Set a universal variable, inheriting as applicable from the given old variable.
@@ -1068,7 +1068,7 @@ impl EnvStackImpl {
                 return cursor;
             }
         }
-        return self.base.globals.clone();
+        self.base.globals.clone()
     }
 
     /// Get an existing variable, or None.
@@ -1158,7 +1158,7 @@ unsafe impl<T> Send for EnvMutex<T> {}
 #[cfg(test)]
 mod tests {
     use super::colon_split;
-    use crate::wchar::prelude::*;
+    use crate::prelude::*;
 
     #[test]
     fn test_colon_split() {
