@@ -1,7 +1,7 @@
 use crate::signal::Signal;
-use crate::wchar::{L, WString, wstr};
 use crate::wcstringutil::join_strings;
 use bitflags::bitflags;
+use fish_wchar::{L, WString, wstr};
 use libc::c_int;
 use std::collections::HashMap;
 use std::sync::Arc;
@@ -164,15 +164,6 @@ impl EnvVar {
         join_strings(&self.values, self.get_delimiter())
     }
 
-    /// Copies the variable's values into an existing list, avoiding reallocation if possible.
-    pub fn to_list(&self, out: &mut Vec<WString>) {
-        // Try to avoid reallocation as much as possible.
-        out.resize(self.values.len(), WString::new());
-        for (i, val) in self.values.iter().enumerate() {
-            out[i].clone_from(val);
-        }
-    }
-
     /// Returns the variable's values.
     pub fn as_list(&self) -> &[WString] {
         &self.values
@@ -239,6 +230,8 @@ pub struct ElectricVar {
     flags: electric::ElectricVarFlags,
 }
 
+pub const FISH_TERMINAL_COLOR_THEME_VAR: &wstr = L!("fish_terminal_color_theme");
+
 // Keep sorted alphabetically
 #[rustfmt::skip]
 pub const ELECTRIC_VARIABLES: &[ElectricVar] = &[
@@ -249,6 +242,7 @@ pub const ELECTRIC_VARIABLES: &[ElectricVar] = &[
     ElectricVar{name: L!("fish_kill_signal"), flags:electric::READONLY | electric::COMPUTED},
     ElectricVar{name: L!("fish_killring"), flags:electric::READONLY | electric::COMPUTED},
     ElectricVar{name: L!("fish_pid"), flags:electric::READONLY},
+    ElectricVar{name: FISH_TERMINAL_COLOR_THEME_VAR, flags:electric::READONLY},
     ElectricVar{name: L!("history"), flags:electric::READONLY | electric::COMPUTED},
     ElectricVar{name: L!("hostname"), flags:electric::READONLY},
     ElectricVar{name: L!("pipestatus"), flags:electric::READONLY | electric::COMPUTED},
@@ -294,8 +288,8 @@ pub fn is_read_only(name: &wstr) -> bool {
 mod tests {
     use super::{EnvMode, EnvVar, EnvVarFlags};
     use crate::env::environment::{EnvStack, Environment};
+    use crate::prelude::*;
     use crate::tests::prelude::*;
-    use crate::wchar::prelude::*;
     use std::{
         mem::MaybeUninit,
         time::{SystemTime, UNIX_EPOCH},
