@@ -2,12 +2,13 @@ use crate::common::{
     UnescapeFlags, UnescapeStringStyle, unescape_string, valid_var_name, wcs2zstring,
 };
 use crate::env::{EnvVar, EnvVarFlags, VarTable};
-use crate::flog::{FLOG, FLOGF};
+use crate::flog::{flog, flogf};
 use crate::fs::{PotentialUpdate, lock_and_load, rewrite_via_temporary_file};
 use crate::path::path_get_config;
-use crate::wchar::{decode_byte_from_char, prelude::*};
+use crate::prelude::*;
 use crate::wcstringutil::{LineIterator, join_strings};
 use crate::wutil::{FileId, INVALID_FILE_ID, file_id_for_file, file_id_for_path_narrow, wrealpath};
+use fish_wchar::decode_byte_from_char;
 use std::collections::HashSet;
 use std::collections::hash_map::Entry;
 use std::ffi::CString;
@@ -30,9 +31,9 @@ pub type CallbackDataList = Vec<CallbackData>;
 // List of fish universal variable formats.
 #[derive(Clone, Copy, Debug, Eq, PartialEq)]
 enum UvarFormat {
-    fish_2_x,
-    fish_3_0,
-    future,
+    Fish_2_x,
+    Fish_3_0,
+    Future,
 }
 
 /// Class representing universal variables.
@@ -162,15 +163,15 @@ impl EnvUniversal {
             return (false, None);
         }
 
-        FLOG!(uvar_file, "universal log sync");
+        flog!(uvar_file, "universal log sync");
         // If we have no changes, just load.
         if self.modified.is_empty() {
             let callbacks = self.load_from_path_narrow();
-            FLOG!(uvar_file, "universal log no modifications");
+            flog!(uvar_file, "universal log no modifications");
             return (false, callbacks);
         }
 
-        FLOG!(uvar_file, "universal log performing full sync");
+        flog!(uvar_file, "universal log performing full sync");
 
         let rewrite = |old_file: &File,
                        tmp_file: &mut File|
@@ -221,7 +222,7 @@ impl EnvUniversal {
                 }
             }
             Err(e) => {
-                FLOG!(uvar_file, "universal log sync failed:", e);
+                flog!(uvar_file, "universal log sync failed:", e);
                 (false, None)
             }
         }
@@ -250,14 +251,14 @@ impl EnvUniversal {
             wide_line = WString::from_str(line);
 
             match format {
-                UvarFormat::fish_2_x => {
+                UvarFormat::Fish_2_x => {
                     Self::parse_message_2x_internal(&wide_line, out_vars, &mut storage);
                 }
-                UvarFormat::fish_3_0 => {
+                UvarFormat::Fish_3_0 => {
                     Self::parse_message_30_internal(&wide_line, out_vars, &mut storage);
                 }
                 // For future formats, just try with the most recent one.
-                UvarFormat::future => {
+                UvarFormat::Future => {
                     Self::parse_message_30_internal(&wide_line, out_vars, &mut storage);
                 }
             }
@@ -298,13 +299,13 @@ impl EnvUniversal {
             return if versionbuf.starts_with(UVARS_VERSION_3_0)
                 && versionbuf[UVARS_VERSION_3_0.len()] == b'\0'
             {
-                UvarFormat::fish_3_0
+                UvarFormat::Fish_3_0
             } else {
-                UvarFormat::future
+                UvarFormat::Future
             };
         }
         // No version found, assume 2.x
-        return UvarFormat::fish_2_x;
+        UvarFormat::Fish_2_x
     }
 
     /// Serialize a variable list.
@@ -359,11 +360,11 @@ impl EnvUniversal {
         if self.last_read_file_id != INVALID_FILE_ID
             && file_id_for_path_narrow(&self.narrow_vars_path) == self.last_read_file_id
         {
-            FLOG!(uvar_file, "universal log sync elided based on fast stat()");
+            flog!(uvar_file, "universal log sync elided based on fast stat()");
             return None;
         }
 
-        FLOG!(uvar_file, "universal log reading from file");
+        flog!(uvar_file, "universal log reading from file");
         match lock_and_load(&self.vars_path, |f, file_id| {
             Ok(self.load_from_file(f, file_id).map(|update| update.data))
         }) {
@@ -388,7 +389,7 @@ impl EnvUniversal {
                 None
             }
             Err(e) => {
-                FLOG!(uvar_file, "Failed to load from universal variable file:", e);
+                flog!(uvar_file, "Failed to load from universal variable file:", e);
                 None
             }
         }
@@ -408,7 +409,7 @@ impl EnvUniversal {
         current_file_id: FileId,
     ) -> Option<PotentialUpdate<UniversalReadUpdate>> {
         if current_file_id == self.last_read_file_id {
-            FLOG!(uvar_file, "universal log sync elided based on fstat()");
+            flog!(uvar_file, "universal log sync elided based on fstat()");
             None
         } else {
             // Read a variables table from the file.
@@ -417,7 +418,7 @@ impl EnvUniversal {
 
             // Hacky: if the read format is in the future, avoid overwriting the file: never try to
             // save.
-            let do_save = format != UvarFormat::future;
+            let do_save = format != UvarFormat::Future;
 
             // Announce changes and update our exports generation.
             let (export_generation_increment, callbacks) =
@@ -546,7 +547,7 @@ impl EnvUniversal {
 
         let mut cursor = msg;
         if !r#match(&mut cursor, f3::SETUVAR) {
-            FLOGF!(warning, PARSE_ERR, msg);
+            flogf!(warning, PARSE_ERR, msg);
             return;
         }
         // Parse out flags.
@@ -570,7 +571,7 @@ impl EnvUniversal {
 
         // Populate the variable with these flags.
         if !Self::populate_1_variable(cursor, flags, vars, storage) {
-            FLOGF!(warning, PARSE_ERR, msg);
+            flogf!(warning, PARSE_ERR, msg);
         }
     }
 
@@ -587,12 +588,12 @@ impl EnvUniversal {
             flags |= EnvVarFlags::EXPORT;
         } else if r#match(&mut cursor, f2x::SET) {
         } else {
-            FLOGF!(warning, PARSE_ERR, msg);
+            flogf!(warning, PARSE_ERR, msg);
             return;
         }
 
         if !Self::populate_1_variable(cursor, flags, vars, storage) {
-            FLOGF!(warning, PARSE_ERR, msg);
+            flogf!(warning, PARSE_ERR, msg);
         }
     }
 
@@ -604,7 +605,7 @@ impl EnvUniversal {
             .take(u64::try_from(MAX_READ_SIZE).expect("MAX_READ_SIZE must fit into u64"))
             .read_to_end(&mut contents)
         {
-            FLOG!(warning, "Failed to read file:", e);
+            flog!(warning, "Failed to read file:", e);
         }
 
         // Handle overlong files.
@@ -743,7 +744,7 @@ fn append_file_entry(
 
     // Append variable name like "fish_color_cwd".
     if !valid_var_name(key_in) {
-        FLOGF!(error, "Illegal variable name: '%s'", key_in);
+        flogf!(error, "Illegal variable name: '%s'", key_in);
         success = false;
     }
     if success {
@@ -806,27 +807,28 @@ fn skip_spaces(mut s: &wstr) -> &wstr {
 
 #[cfg(test)]
 mod tests {
-    use crate::common::ENCODE_DIRECT_BASE;
-    use crate::common::char_offset;
+    use fish_common::ENCODE_DIRECT_BASE;
+    use fish_common::char_offset;
+    use fish_tempfile::TempDir;
+
+    use crate::common::bytes2wcstring;
     use crate::common::wcs2osstring;
     use crate::env::{EnvVar, EnvVarFlags, VarTable};
     use crate::env_universal_common::{EnvUniversal, UvarFormat};
+    use crate::prelude::*;
     use crate::tests::prelude::*;
-    use crate::wchar::prelude::*;
     use crate::wutil::{INVALID_FILE_ID, file_id_for_path};
 
     const UVARS_PER_THREAD: usize = 8;
 
-    /// Creates a unique temporary directory and file path for universal variable tests.
-    /// Returns (directory_path, file_path).
-    fn make_test_uvar_path(test_name: &str) -> (std::path::PathBuf, WString) {
-        let test_dir = std::env::temp_dir().join(format!(
-            "fish_test_{}_{:?}",
-            test_name,
-            std::thread::current().id()
-        ));
-        let test_path = sprintf!("%s/varsfile.txt", test_dir.to_string_lossy());
-        (test_dir, test_path)
+    /// Creates a unique temporary directory and file path for universal variable tests inside the
+    /// new tempdir.
+    /// Returns (temp_dir, file_path).
+    fn make_test_uvar_path() -> std::io::Result<(TempDir, WString)> {
+        let temp_dir = fish_tempfile::new_dir()?;
+        let file_path = temp_dir.path().join("varsfile.txt");
+        let file_path = bytes2wcstring(file_path.as_os_str().as_encoded_bytes());
+        Ok((temp_dir, file_path))
     }
 
     fn test_universal_helper(x: usize, path: &wstr) {
@@ -854,9 +856,7 @@ mod tests {
     #[test]
     fn test_universal() {
         let _cleanup = test_init();
-        let (test_dir, test_path) = make_test_uvar_path("universal");
-        let _ = std::fs::remove_dir_all(&test_dir);
-        std::fs::create_dir_all(&test_dir).unwrap();
+        let (_test_dir, test_path) = make_test_uvar_path().unwrap();
 
         let threads = 1;
         let mut handles = Vec::new();
@@ -890,8 +890,6 @@ mod tests {
                 assert_eq!(var, expected_val);
             }
         }
-
-        std::fs::remove_dir_all(&test_dir).unwrap();
     }
 
     #[test]
@@ -1035,8 +1033,7 @@ mod tests {
     #[test]
     fn test_universal_callbacks() {
         let _cleanup = test_init();
-        let (test_dir, test_path) = make_test_uvar_path("callbacks");
-        std::fs::create_dir_all(&test_dir).unwrap();
+        let (_test_dir, test_path) = make_test_uvar_path().unwrap();
         let mut uvars1 = EnvUniversal::new();
         let mut uvars2 = EnvUniversal::new();
         let mut callbacks = uvars1
@@ -1100,7 +1097,6 @@ mod tests {
         assert_eq!(callbacks[1].val.as_ref().unwrap().as_string(), L!("1"));
         assert_eq!(callbacks[2].key, L!("delta"));
         assert_eq!(callbacks[2].val, None);
-        std::fs::remove_dir_all(&test_dir).unwrap();
     }
 
     #[test]
@@ -1115,22 +1111,21 @@ mod tests {
                 );
             };
         }
-        validate!(b"# VERSION: 3.0", UvarFormat::fish_3_0);
-        validate!(b"# version: 3.0", UvarFormat::fish_2_x);
-        validate!(b"# blah blahVERSION: 3.0", UvarFormat::fish_2_x);
-        validate!(b"stuff\n# blah blahVERSION: 3.0", UvarFormat::fish_2_x);
-        validate!(b"# blah\n# VERSION: 3.0", UvarFormat::fish_3_0);
-        validate!(b"# blah\n#VERSION: 3.0", UvarFormat::fish_3_0);
-        validate!(b"# blah\n#VERSION:3.0", UvarFormat::fish_3_0);
-        validate!(b"# blah\n#VERSION:3.1", UvarFormat::future);
+        validate!(b"# VERSION: 3.0", UvarFormat::Fish_3_0);
+        validate!(b"# version: 3.0", UvarFormat::Fish_2_x);
+        validate!(b"# blah blahVERSION: 3.0", UvarFormat::Fish_2_x);
+        validate!(b"stuff\n# blah blahVERSION: 3.0", UvarFormat::Fish_2_x);
+        validate!(b"# blah\n# VERSION: 3.0", UvarFormat::Fish_3_0);
+        validate!(b"# blah\n#VERSION: 3.0", UvarFormat::Fish_3_0);
+        validate!(b"# blah\n#VERSION:3.0", UvarFormat::Fish_3_0);
+        validate!(b"# blah\n#VERSION:3.1", UvarFormat::Future);
     }
 
     #[test]
     fn test_universal_ok_to_save() {
         let _cleanup = test_init();
         // Ensure we don't try to save after reading from a newer fish.
-        let (test_dir, test_path) = make_test_uvar_path("ok_to_save");
-        std::fs::create_dir_all(&test_dir).unwrap();
+        let (_test_dir, test_path) = make_test_uvar_path().unwrap();
         let contents = b"# VERSION: 99999.99\n";
         std::fs::write(wcs2osstring(&test_path), contents).unwrap();
 
@@ -1152,6 +1147,5 @@ mod tests {
         // Ensure file is same.
         let after_id = file_id_for_path(&test_path);
         assert_eq!(before_id, after_id, "test_path should not have changed",);
-        std::fs::remove_dir_all(&test_dir).unwrap();
     }
 }
