@@ -12,18 +12,18 @@ use crate::common::{
     write_loop,
 };
 use crate::env::{EnvMode, EnvStack, Environment, READ_BYTE_LIMIT, Statuses};
-#[cfg(FISH_USE_POSIX_SPAWN)]
+#[cfg(have_posix_spawn)]
 use crate::env_dispatch::use_posix_spawn;
 use crate::fds::make_fd_blocking;
 use crate::fds::{PIPE_ERROR, make_autoclose_pipes, open_cloexec};
-use crate::flog::{FLOG, FLOGF};
+use crate::flog::{flog, flogf};
 use crate::fork_exec::PATH_BSHELL;
 use crate::fork_exec::blocked_signals_for_job;
 use crate::fork_exec::postfork::{
     child_setup_process, execute_fork, execute_setpgid, report_setpgid_error,
     safe_report_exec_error,
 };
-#[cfg(FISH_USE_POSIX_SPAWN)]
+#[cfg(have_posix_spawn)]
 use crate::fork_exec::spawn::PosixSpawner;
 use crate::function::{self, FunctionProperties};
 use crate::io::{
@@ -33,7 +33,7 @@ use crate::io::{
 use crate::nix::{getpid, isatty};
 use crate::null_terminated_array::OwningNullTerminatedArray;
 use crate::parser::{Block, BlockId, BlockType, EvalRes, Parser};
-#[cfg(FISH_USE_POSIX_SPAWN)]
+use crate::prelude::*;
 use crate::proc::Pid;
 use crate::proc::{
     InternalProc, Job, JobGroupRef, ProcStatus, Process, ProcessType, hup_jobs,
@@ -44,13 +44,12 @@ use crate::redirection::{Dup2List, dup2_list_resolve_chain};
 use crate::threads::{ThreadPool, is_forked_child};
 use crate::trace::trace_if_enabled_with_args;
 use crate::tty_handoff::TtyHandoff;
-use crate::wchar::prelude::*;
-use crate::wchar_ext::ToWString;
 use crate::wutil::{fish_wcstol, perror};
 use errno::{errno, set_errno};
+use fish_wchar::ToWString;
 use libc::{
     EACCES, ENOENT, ENOEXEC, ENOTDIR, EPIPE, EXIT_FAILURE, EXIT_SUCCESS, STDERR_FILENO,
-    STDIN_FILENO, STDOUT_FILENO, c_char,
+    STDIN_FILENO, STDOUT_FILENO,
 };
 use nix::fcntl::OFlag;
 use nix::sys::stat;
@@ -149,7 +148,7 @@ pub fn exec_job(parser: &Parser, job: &Job, block_io: IoChain) -> bool {
         std::mem::swap(&mut proc_pipes.read, &mut pipe_next_read);
         if !p.is_last_in_job {
             let Ok(pipes) = make_autoclose_pipes() else {
-                FLOG!(warning, wgettext!(PIPE_ERROR));
+                flog!(warning, wgettext!(PIPE_ERROR));
                 aborted_pipeline = true;
                 abort_pipeline_from(job, i);
                 break;
@@ -211,7 +210,7 @@ pub fn exec_job(parser: &Parser, job: &Job, block_io: IoChain) -> bool {
                 parser,
                 &job.processes()[dp],
                 job,
-                block_io,
+                block_io.clone(),
                 deferred_pipes,
                 &PartialPipes::default(),
                 true,
@@ -222,7 +221,7 @@ pub fn exec_job(parser: &Parser, job: &Job, block_io: IoChain) -> bool {
         }
     }
 
-    FLOGF!(
+    flogf!(
         exec_job_exec,
         "Executed job %d from command '%s'",
         job.job_id(),
@@ -244,7 +243,7 @@ pub fn exec_job(parser: &Parser, job: &Job, block_io: IoChain) -> bool {
     }
 
     if !job.is_initially_background() {
-        job.continue_job(parser);
+        job.continue_job(parser, Some(&block_io));
     }
 
     if job.is_stopped() {
@@ -415,8 +414,8 @@ fn safe_launch_process(
         if nargs <= MAXARGS {
             // +1 for /bin/sh, +1 for terminating nullptr
             let mut argv2 = [std::ptr::null(); 1 + MAXARGS + 1];
-            let bshell = PATH_BSHELL.as_ptr() as *const c_char;
-            argv2[0] = bshell as *mut c_char;
+            let bshell = PATH_BSHELL.as_ptr().cast();
+            argv2[0] = bshell;
             argv2[1..argv.len() + 1].copy_from_slice(argv);
             // The command to call should use the full path,
             // not what we would pass as argv0.
@@ -456,7 +455,7 @@ fn launch_process_nofork(vars: &EnvStack, p: &Process) -> ! {
 // To avoid the race between the caller calling tcsetpgrp() and the client checking the
 // foreground process group, we don't use posix_spawn if we're going to foreground the process. (If
 // we use fork(), we can call tcsetpgrp after the fork, before the exec, and avoid the race).
-#[cfg(FISH_USE_POSIX_SPAWN)]
+#[cfg(have_posix_spawn)]
 fn can_use_posix_spawn_for_job(job: &Job, dup2s: &Dup2List) -> bool {
     // Is it globally disabled?
     if !use_posix_spawn() {
@@ -580,7 +579,7 @@ fn run_internal_process(p: &Process, outdata: Vec<u8>, errdata: Vec<u8>, ios: &I
         success_status: ProcStatus::default(),
     });
 
-    FLOGF!(
+    flogf!(
         proc_internal_proc,
         "Created internal proc %u to write output for proc '%s'",
         internal_proc.get_id(),
@@ -652,7 +651,7 @@ fn run_internal_process_or_short_circuit(
     if outdata.is_empty() && errdata.is_empty() {
         p.completed.store(true);
         if p.is_last_in_job {
-            FLOGF!(
+            flogf!(
                 exec_job_status,
                 "Set status of job %d (%s) to %d using short circuit",
                 j.job_id(),
@@ -766,7 +765,7 @@ fn fork_child_for_process(
     }
 
     let count = FORK_COUNT.fetch_add(1, Ordering::Relaxed) + 1;
-    FLOGF!(
+    flogf!(
         exec_fork,
         "Fork #%d, pid %d fork external command for '%s'",
         count,
@@ -791,21 +790,21 @@ fn create_output_stream_for_builtin(
         return OutputStream::Fd(FdOutputStream::new(fd));
     };
     match io.io_mode() {
-        IoMode::bufferfill => {
+        IoMode::BufferFill => {
             // Our IO redirection is to an internal buffer, e.g. a command substitution.
             // We will write directly to it.
             let buffer = io.as_bufferfill().unwrap().buffer();
             OutputStream::Buffered(BufferedOutputStream::new(buffer.clone()))
         }
-        IoMode::close => {
+        IoMode::Close => {
             // Like 'echo foo >&-'
             OutputStream::Null
         }
-        IoMode::file => {
+        IoMode::File => {
             // Output is to a file which has been opened.
             OutputStream::Fd(FdOutputStream::new(io.source_fd()))
         }
-        IoMode::pipe => {
+        IoMode::Pipe => {
             // Output is to a pipe. We may need to buffer.
             if piped_output_needs_buffering {
                 OutputStream::String(StringOutputStream::new())
@@ -813,7 +812,7 @@ fn create_output_stream_for_builtin(
                 OutputStream::Fd(FdOutputStream::new(io.source_fd()))
             }
         }
-        IoMode::fd => {
+        IoMode::Fd => {
             // This is a case like 'echo foo >&5'
             // It's uncommon and unclear what should happen.
             OutputStream::String(StringOutputStream::new())
@@ -884,7 +883,7 @@ fn exec_external_command(
 
     let actual_cmd = wcs2zstring(&p.actual_cmd);
 
-    #[cfg(FISH_USE_POSIX_SPAWN)]
+    #[cfg(have_posix_spawn)]
     // Prefer to use posix_spawn, since it's faster on some systems like OS X.
     if can_use_posix_spawn_for_job(j, &dup2s) {
         let file = &parser.libdata().current_filename;
@@ -902,7 +901,7 @@ fn exec_external_command(
                 return Err(());
             }
         };
-        FLOGF!(
+        flogf!(
             exec_fork,
             "Fork #%d, pid %d: spawn external command '%s' from '%s'",
             count,
@@ -1034,7 +1033,7 @@ fn get_performer_for_function(
     let io_chain = io_chain.clone();
     // This may occur if the function was erased as part of its arguments or in other strange edge cases.
     let Some(props) = function::get_props(p.argv0().unwrap()) else {
-        FLOG!(
+        flog!(
             error,
             wgettext_fmt!("Unknown function '%s'", p.argv0().unwrap())
         );
@@ -1159,7 +1158,7 @@ fn get_performer_for_builtin(p: &Process, j: &Job, io_chain: &IoChain) -> Box<Pr
                 // which is internal to fish. We still respect this redirection in
                 // that we pass it on as a block IO to the code that source runs,
                 // and therefore this is not an error.
-                let ignore_redirect = inp.io_mode() == IoMode::fd && inp.source_fd() >= 3;
+                let ignore_redirect = inp.io_mode() == IoMode::Fd && inp.source_fd() >= 3;
                 if !ignore_redirect {
                     local_builtin_stdin = inp.source_fd();
                 }
@@ -1172,8 +1171,8 @@ fn get_performer_for_builtin(p: &Process, j: &Job, io_chain: &IoChain) -> Box<Pr
             streams.stdin_is_directly_redirected = stdin_is_directly_redirected;
             streams.out_is_redirected = out_io.is_some();
             streams.err_is_redirected = err_io.is_some();
-            streams.out_is_piped = out_io.is_some_and(|io| io.io_mode() == IoMode::pipe);
-            streams.err_is_piped = err_io.is_some_and(|io| io.io_mode() == IoMode::pipe);
+            streams.out_is_piped = out_io.is_some_and(|io| io.io_mode() == IoMode::Pipe);
+            streams.err_is_piped = err_io.is_some_and(|io| io.io_mode() == IoMode::Pipe);
 
             // Disallow nul bytes in the arguments, as they are not allowed in builtins.
             let mut shim_argv: Vec<&wstr> =
@@ -1345,7 +1344,6 @@ fn exec_process_in_job(
             piped_output_needs_buffering,
         ),
         ProcessType::External => {
-            parser.libdata_mut().exec_external_count += 1;
             exec_external_command(parser, j, p, &process_net_io_chain)?;
             // It's possible (though unlikely) that this is a background process which recycled a
             // pid from another, previous background process. Forget any such old process.
@@ -1447,7 +1445,7 @@ fn populate_subshell_output(lst: &mut Vec<WString>, buffer: &SeparatedBuffer, sp
                 let stop = data[cursor..].iter().position(|c| *c == b'\n');
                 let hit_separator = stop.is_some();
                 // If it's not found, just use the end.
-                let stop = stop.map(|rel| cursor + rel).unwrap_or(data.len());
+                let stop = stop.map_or(data.len(), |rel| cursor + rel);
                 // Stop now points at the first character we do not want to copy.
                 lst.push(bytes2wcstring(&data[cursor..stop]));
 
