@@ -1,7 +1,7 @@
 // The stuff that happens after fork.
 // Everything in this module must be async-signal safe.
 // That means no locking, no allocating, no freeing memory, etc!
-use super::flog_safe::FLOG_SAFE;
+use super::flog_safe::flog_safe;
 use crate::nix::getpid;
 use crate::null_terminated_array::OwningNullTerminatedArray;
 use crate::redirection::Dup2List;
@@ -29,9 +29,9 @@ fn clear_cloexec(fd: i32) -> i32 {
     }
     let new_flags = flags & !libc::FD_CLOEXEC;
     if flags == new_flags {
-        return 0;
+        0
     } else {
-        return unsafe { libc::fcntl(fd, libc::F_SETFD, new_flags) };
+        unsafe { libc::fcntl(fd, libc::F_SETFD, new_flags) }
     }
 }
 
@@ -47,7 +47,7 @@ pub(crate) fn report_setpgid_error(
 ) {
     let cur_group = unsafe { libc::getpgid(pid) };
 
-    FLOG_SAFE!(
+    flog_safe!(
         warning,
         "Could not send ",
         if is_parent { "child" } else { "self" },
@@ -66,10 +66,10 @@ pub(crate) fn report_setpgid_error(
     );
 
     match err {
-        libc::EACCES => FLOG_SAFE!(error, "setpgid: Process ", pid, " has already exec'd"),
-        libc::EINVAL => FLOG_SAFE!(error, "setpgid: pgid ", cur_group, " unsupported"),
+        libc::EACCES => flog_safe!(error, "setpgid: Process ", pid, " has already exec'd"),
+        libc::EINVAL => flog_safe!(error, "setpgid: pgid ", cur_group, " unsupported"),
         libc::EPERM => {
-            FLOG_SAFE!(
+            flog_safe!(
                 error,
                 "setpgid: Process ",
                 pid,
@@ -78,8 +78,8 @@ pub(crate) fn report_setpgid_error(
                 " does not match"
             );
         }
-        libc::ESRCH => FLOG_SAFE!(error, "setpgid: Process ID ", pid, " does not match"),
-        _ => FLOG_SAFE!(error, "setpgid: Unknown error number ", err),
+        libc::ESRCH => flog_safe!(error, "setpgid: Process ID ", pid, " does not match"),
+        _ => flog_safe!(error, "setpgid: Unknown error number ", err),
     }
 }
 
@@ -94,13 +94,11 @@ pub fn execute_setpgid(pid: libc::pid_t, pgroup: libc::pid_t, is_parent: bool) -
             return 0;
         }
         let err = errno::errno().0;
+        assert!(err != libc::EINTR);
         if err == libc::EACCES && is_parent {
             // We are the parent process and our child has called exec().
             // This is an unavoidable benign race.
             return 0;
-        } else if err == libc::EINTR {
-            // Paranoia.
-            continue;
         } else if err == libc::EPERM && eperm_count < 100 {
             eperm_count += 1;
             // The setpgid(2) man page says that EPERM is returned only if attempts are made
@@ -108,7 +106,7 @@ pub fn execute_setpgid(pid: libc::pid_t, pgroup: libc::pid_t, is_parent: bool) -
             // the case in fish, anywhere) or to change the process group ID of a session
             // leader (again, can never be the case). I'm pretty sure this is a WSL bug, as
             // we see the same with tcsetpgrp(2) in other places and it disappears on retry.
-            FLOG_SAFE!(proc_pgroup, "setpgid(2) returned EPERM. Retrying");
+            flog_safe!(proc_pgroup, "setpgid(2) returned EPERM. Retrying");
             continue;
         }
 
@@ -152,7 +150,7 @@ pub fn child_setup_process(
         }
         if err < 0 {
             if is_forked {
-                FLOG_SAFE!(
+                flog_safe!(
                     warning,
                     "failed to set up file descriptors in child_setup_process"
                 );
@@ -211,16 +209,16 @@ pub fn execute_fork() -> pid_t {
 
     match err {
         libc::EAGAIN => {
-            FLOG_SAFE!(
+            flog_safe!(
                 error,
                 "fork: Out of resources. Check RLIMIT_NPROC and pid_max."
             );
         }
         libc::ENOMEM => {
-            FLOG_SAFE!(error, "fork: Out of memory.");
+            flog_safe!(error, "fork: Out of memory.");
         }
         _ => {
-            FLOG_SAFE!(error, "fork: Unknown error number", err);
+            flog_safe!(error, "fork: Unknown error number", err);
         }
     }
     exit_without_destructors(1)
@@ -241,7 +239,7 @@ pub(crate) fn safe_report_exec_error(
             if arg_max > 0 {
                 let arg_max = arg_max as usize;
                 if sz >= arg_max {
-                    FLOG_SAFE!(
+                    flog_safe!(
                         exec,
                         "Failed to execute process '",
                         actual_cmd,
@@ -255,7 +253,7 @@ pub(crate) fn safe_report_exec_error(
                     // MAX_ARG_STRLEN, a linux thing that limits the size of one argument. It's
                     // defined in binfmts.h, but we don't want to include that just to be able to
                     // print the real limit.
-                    FLOG_SAFE!(
+                    flog_safe!(
                         exec,
                         "Failed to execute process '",
                         actual_cmd,
@@ -264,14 +262,14 @@ pub(crate) fn safe_report_exec_error(
                 }
 
                 if szenv >= arg_max / 2 {
-                    FLOG_SAFE!(
+                    flog_safe!(
                         exec,
                         "Hint: Your exported variables take up over half the limit. Try \
                          erasing or unexporting variables."
                     );
                 }
             } else {
-                FLOG_SAFE!(
+                flog_safe!(
                     exec,
                     "Failed to execute process '",
                     actual_cmd,
@@ -283,7 +281,7 @@ pub(crate) fn safe_report_exec_error(
         }
 
         libc::ENOEXEC => {
-            FLOG_SAFE!(
+            flog_safe!(
                 exec,
                 "Failed to execute process: '",
                 actual_cmd,
@@ -293,7 +291,7 @@ pub(crate) fn safe_report_exec_error(
             if get_interpreter(actual_cmd, &mut interpreter_buf).is_none() {
                 // Paths ending in ".fish" need to start with a shebang
                 if actual_cmd.to_bytes().ends_with(b".fish") {
-                    FLOG_SAFE!(
+                    flog_safe!(
                         exec,
                         "fish scripts require an interpreter directive (must \
                          start with '#!/path/to/fish')."
@@ -301,7 +299,7 @@ pub(crate) fn safe_report_exec_error(
                 } else {
                     // If the shebang line exists, we would get an ENOENT or similar instead,
                     // so I don't know how to reach this.
-                    FLOG_SAFE!(exec, "Maybe the interpreter directive (#! line) is broken?");
+                    flog_safe!(exec, "Maybe the interpreter directive (#! line) is broken?");
                 }
             }
         }
@@ -323,14 +321,14 @@ pub(crate) fn safe_report_exec_error(
                     // Detect Windows line endings and complain specifically about them.
                     let interpreter = interpreter.to_bytes();
                     if interpreter.last() == Some(&b'\r') {
-                        FLOG_SAFE!(
+                        flog_safe!(
                             exec,
                             "Failed to execute process '",
                             actual_cmd,
                             "':  The file uses Windows line endings (\\r\\n). Run dos2unix or similar to fix it."
                         );
                     } else {
-                        FLOG_SAFE!(
+                        flog_safe!(
                             exec,
                             "Failed to execute process '",
                             actual_cmd,
@@ -347,7 +345,7 @@ pub(crate) fn safe_report_exec_error(
                         err_or_no_exec_handling(interpreter, actual_cmd);
                     } else if metadata.mode() & u32::from(libc::S_IFMT) == u32::from(libc::S_IFDIR)
                     {
-                        FLOG_SAFE!(
+                        flog_safe!(
                             exec,
                             "Failed to execute process '",
                             actual_cmd,
@@ -360,21 +358,21 @@ pub(crate) fn safe_report_exec_error(
                     err_or_no_exec_handling(interpreter, actual_cmd);
                 }
             } else if unsafe { libc::access(actual_cmd.as_ptr(), libc::X_OK) } == 0 {
-                FLOG_SAFE!(
+                flog_safe!(
                     exec,
                     "Failed to execute process '",
                     actual_cmd,
                     "': The file exists and is executable. Check the interpreter or linker?"
                 );
             } else if err == libc::ENOENT {
-                FLOG_SAFE!(
+                flog_safe!(
                     exec,
                     "Failed to execute process '",
                     actual_cmd,
                     "': The file does not exist or could not be executed."
                 );
             } else {
-                FLOG_SAFE!(
+                flog_safe!(
                     exec,
                     "Failed to execute process '",
                     actual_cmd,
@@ -384,11 +382,11 @@ pub(crate) fn safe_report_exec_error(
         }
 
         libc::ENOMEM => {
-            FLOG_SAFE!(exec, "Out of memory");
+            flog_safe!(exec, "Out of memory");
         }
 
         libc::ETXTBSY => {
-            FLOG_SAFE!(
+            flog_safe!(
                 exec,
                 "Failed to execute process '",
                 actual_cmd,
@@ -397,7 +395,7 @@ pub(crate) fn safe_report_exec_error(
         }
 
         libc::ELOOP => {
-            FLOG_SAFE!(
+            flog_safe!(
                 exec,
                 "Failed to execute process '",
                 actual_cmd,
@@ -406,7 +404,7 @@ pub(crate) fn safe_report_exec_error(
         }
 
         libc::EINVAL => {
-            FLOG_SAFE!(
+            flog_safe!(
                 exec,
                 "Failed to execute process '",
                 actual_cmd,
@@ -414,7 +412,7 @@ pub(crate) fn safe_report_exec_error(
             );
         }
         libc::EISDIR => {
-            FLOG_SAFE!(
+            flog_safe!(
                 exec,
                 "Failed to execute process '",
                 actual_cmd,
@@ -422,7 +420,7 @@ pub(crate) fn safe_report_exec_error(
             );
         }
         libc::ENOTDIR => {
-            FLOG_SAFE!(
+            flog_safe!(
                 exec,
                 "Failed to execute process '",
                 actual_cmd,
@@ -431,7 +429,7 @@ pub(crate) fn safe_report_exec_error(
         }
 
         libc::EMFILE => {
-            FLOG_SAFE!(
+            flog_safe!(
                 exec,
                 "Failed to execute process '",
                 actual_cmd,
@@ -439,7 +437,7 @@ pub(crate) fn safe_report_exec_error(
             );
         }
         libc::ENFILE => {
-            FLOG_SAFE!(
+            flog_safe!(
                 exec,
                 "Failed to execute process '",
                 actual_cmd,
@@ -447,7 +445,7 @@ pub(crate) fn safe_report_exec_error(
             );
         }
         libc::ENAMETOOLONG => {
-            FLOG_SAFE!(
+            flog_safe!(
                 exec,
                 "Failed to execute process '",
                 actual_cmd,
@@ -455,7 +453,7 @@ pub(crate) fn safe_report_exec_error(
             );
         }
         libc::EPERM => {
-            FLOG_SAFE!(
+            flog_safe!(
                 exec,
                 "Failed to execute process '",
                 actual_cmd,
@@ -466,7 +464,7 @@ pub(crate) fn safe_report_exec_error(
 
         #[cfg(apple)]
         libc::EBADARCH => {
-            FLOG_SAFE!(
+            flog_safe!(
                 exec,
                 "Failed to execute process '",
                 actual_cmd,
@@ -475,7 +473,7 @@ pub(crate) fn safe_report_exec_error(
         }
 
         err => {
-            FLOG_SAFE!(
+            flog_safe!(
                 exec,
                 "Failed to execute process '",
                 actual_cmd,
@@ -495,13 +493,7 @@ fn get_interpreter<'a>(command: &CStr, buffer: &'a mut [u8]) -> Option<&'a CStr>
     if fd >= 0 {
         while idx + 1 < buffer.len() {
             let mut ch = b'\0';
-            let amt = unsafe {
-                libc::read(
-                    fd,
-                    std::ptr::addr_of_mut!(ch).cast(),
-                    std::mem::size_of_val(&ch),
-                )
-            };
+            let amt = unsafe { libc::read(fd, (&raw mut ch).cast(), std::mem::size_of_val(&ch)) };
             if amt <= 0 || ch == b'\n' {
                 break;
             }
