@@ -27,12 +27,11 @@ use crate::parse_util::{
 };
 use crate::path::{path_as_implicit_cd, path_get_cdpath, path_get_path, paths_are_same_file};
 use crate::terminal::Outputter;
-use crate::text_face::{TextFace, UnderlineStyle, parse_text_face};
+use crate::text_face::{SpecifiedTextFace, TextFace, UnderlineStyle, parse_text_face};
 use crate::threads::assert_is_background_thread;
 use crate::tokenizer::{PipeOrRedir, variable_assignment_equals_pos};
-use crate::wchar::{L, WString, wstr};
-use crate::wchar_ext::WExt;
 use crate::wcstringutil::string_prefixes_string;
+use fish_wchar::{L, WExt, WString, wstr};
 use std::collections::HashMap;
 use std::collections::hash_map::Entry;
 
@@ -76,6 +75,9 @@ pub fn colorize(text: &wstr, colors: &[HighlightSpec], vars: &dyn Environment) -
             outp.set_text_face(face);
             last_color = color;
         }
+        if i + 1 == text.char_count() && c == '\n' {
+            outp.set_text_face(TextFace::default());
+        }
         outp.writech(c);
     }
     outp.set_text_face(TextFace::default());
@@ -134,17 +136,25 @@ impl HighlightColorResolver {
             }
         }
     }
-    pub(crate) fn resolve_spec_uncached(
-        highlight: &HighlightSpec,
-        vars: &dyn Environment,
-    ) -> TextFace {
+    fn resolve_spec_uncached(highlight: &HighlightSpec, vars: &dyn Environment) -> TextFace {
         let resolve_role = |role| {
-            vars.get_unless_empty(get_highlight_var_name(role))
-                .or_else(|| vars.get_unless_empty(get_highlight_var_name(get_fallback(role))))
-                .or_else(|| vars.get_unless_empty(get_highlight_var_name(HighlightRole::normal)))
-                .as_ref()
-                .map(parse_text_face_for_highlight)
-                .unwrap_or_else(TextFace::default)
+            let mut roles: &[HighlightRole] = &[role, get_fallback(role), HighlightRole::normal];
+            // TODO(MSRV>=?) partition_dedup
+            for i in [2, 1] {
+                if roles[i - 1] == roles[i] {
+                    roles = &roles[..i];
+                }
+            }
+            for &role in roles {
+                if let Some(face) = vars
+                    .get_unless_empty(get_highlight_var_name(role))
+                    .as_ref()
+                    .and_then(parse_text_face_for_highlight)
+                {
+                    return face;
+                }
+            }
+            TextFace::default()
         };
         let mut face = resolve_role(highlight.foreground);
 
@@ -161,7 +171,8 @@ impl HighlightColorResolver {
         if highlight.valid_path {
             if let Some(valid_path_var) = vars.get(L!("fish_color_valid_path")) {
                 // Historical behavior is to not apply background.
-                let valid_path_face = parse_text_face_for_highlight(&valid_path_var);
+                let valid_path_face =
+                    parse_text_face_for_highlight(&valid_path_var).unwrap_or_default();
                 // Apply the foreground, except if it's normal. The intention here is likely
                 // to only override foreground if the valid path color has an explicit foreground.
                 if !valid_path_face.fg.is_normal() {
@@ -180,19 +191,21 @@ impl HighlightColorResolver {
 }
 
 /// Return the internal color code representing the specified color.
-pub(crate) fn parse_text_face_for_highlight(var: &EnvVar) -> TextFace {
+pub(crate) fn parse_text_face_for_highlight(var: &EnvVar) -> Option<TextFace> {
     let face = parse_text_face(var.as_list());
-    let default = TextFace::default();
-    let fg = face.fg.unwrap_or(default.fg);
-    let bg = face.bg.unwrap_or(default.bg);
-    let underline_color = face.underline_color.unwrap_or(default.underline_color);
-    let style = face.style;
-    TextFace {
-        fg,
-        bg,
-        underline_color,
-        style,
-    }
+    (face != SpecifiedTextFace::default()).then(|| {
+        let default = TextFace::default();
+        let fg = face.fg.unwrap_or(default.fg);
+        let bg = face.bg.unwrap_or(default.bg);
+        let underline_color = face.underline_color.unwrap_or(default.underline_color);
+        let style = face.style.unwrap_or_default();
+        TextFace {
+            fg,
+            bg,
+            underline_color,
+            style,
+        }
+    })
 }
 
 fn command_is_valid(
@@ -209,14 +222,14 @@ fn command_is_valid(
     let mut implicit_cd_ok = true;
     if matches!(
         decoration,
-        StatementDecoration::command | StatementDecoration::exec
+        StatementDecoration::Command | StatementDecoration::Exec
     ) {
         builtin_ok = false;
         function_ok = false;
         abbreviation_ok = false;
         command_ok = true;
         implicit_cd_ok = false;
-    } else if decoration == StatementDecoration::builtin {
+    } else if decoration == StatementDecoration::Builtin {
         builtin_ok = true;
         function_ok = false;
         abbreviation_ok = false;
@@ -253,7 +266,7 @@ fn command_is_valid(
     }
 
     // Return what we got.
-    return is_valid;
+    is_valid
 }
 
 fn has_expand_reserved(s: &wstr) -> bool {
@@ -331,9 +344,7 @@ pub fn autosuggest_validate_from_history(
             // Check the directory target, respecting CDPATH.
             // Permit the autosuggestion if the path is valid and not our directory.
             let path = path_get_cdpath(&cd_dir, working_directory, ctx.vars());
-            return path
-                .map(|p| !paths_are_same_file(working_directory, &p))
-                .unwrap_or(false);
+            return path.is_some_and(|p| !paths_are_same_file(working_directory, &p));
         }
     }
 
@@ -555,7 +566,7 @@ fn color_string_internal(buffstr: &wstr, base_color: HighlightSpec, colors: &mut
                             in_pos -= 1;
                         }
                         '?' => {
-                            if !feature_test(FeatureFlag::qmark_noglob) {
+                            if !feature_test(FeatureFlag::QuestionMarkNoGlob) {
                                 colors[in_pos] = HighlightSpec::with_fg(HighlightRole::operat);
                             }
                         }
@@ -864,14 +875,14 @@ impl<'s> Highlighter<'s> {
     fn visit_token(&mut self, tok: &dyn Token) {
         let mut role = HighlightRole::normal;
         match tok.token_type() {
-            ParseTokenType::end | ParseTokenType::pipe | ParseTokenType::background => {
+            ParseTokenType::End | ParseTokenType::Pipe | ParseTokenType::Background => {
                 role = HighlightRole::statement_terminator
             }
-            ParseTokenType::left_brace | ParseTokenType::right_brace => {
+            ParseTokenType::LeftBrace | ParseTokenType::RightBrace => {
                 role = HighlightRole::keyword;
             }
-            ParseTokenType::andand | ParseTokenType::oror => role = HighlightRole::operat,
-            ParseTokenType::string => {
+            ParseTokenType::AndAnd | ParseTokenType::OrOr => role = HighlightRole::operat,
+            ParseTokenType::String => {
                 // Assume all strings are params. This handles e.g. the variables a for header or
                 // function header. Other strings (like arguments to commands) need more complex
                 // handling, which occurs in their respective overrides of visit().
@@ -1072,9 +1083,9 @@ impl<'s> Highlighter<'s> {
 fn has_cmdsub(src: &wstr) -> bool {
     let mut cursor = 0;
     match parse_util_locate_cmdsubst_range(src, &mut cursor, true, None, None) {
-        MaybeParentheses::Error => return false,
-        MaybeParentheses::None => return false,
-        MaybeParentheses::CommandSubstitution(_) => return true,
+        MaybeParentheses::Error => false,
+        MaybeParentheses::None => false,
+        MaybeParentheses::CommandSubstitution(_) => true,
     }
 }
 
@@ -1107,7 +1118,7 @@ impl<'s, 'a> NodeVisitor<'a> for Highlighter<'s> {
             return self.visit_keyword(keyword);
         }
         if let Some(token) = node.as_token() {
-            if token.token_type() == ParseTokenType::end {
+            if token.token_type() == ParseTokenType::End {
                 self.visit_semi_nl(node);
                 return;
             }
@@ -1263,12 +1274,13 @@ pub struct HighlightSpec {
 mod tests {
     use super::{HighlightColorResolver, HighlightRole, HighlightSpec, highlight_shell};
     use crate::common::ScopeGuard;
-    use crate::env::EnvMode;
+    use crate::env::{EnvMode, Environment};
     use crate::future_feature_flags::{self, FeatureFlag};
+    use crate::highlight::parse_text_face_for_highlight;
     use crate::operation_context::{EXPANSION_LIMIT_BACKGROUND, OperationContext};
+    use crate::prelude::*;
     use crate::tests::prelude::*;
     use crate::text_face::UnderlineStyle;
-    use crate::wchar::prelude::*;
     use libc::PATH_MAX;
 
     // Helper to return a string whose length greatly exceeds PATH_MAX.
@@ -1364,10 +1376,10 @@ mod tests {
         let mut param_valid_path = HighlightSpec::with_fg(HighlightRole::param);
         param_valid_path.valid_path = true;
 
-        let saved_flag = future_feature_flags::test(FeatureFlag::ampersand_nobg_in_token);
-        future_feature_flags::set(FeatureFlag::ampersand_nobg_in_token, true);
+        let saved_flag = future_feature_flags::test(FeatureFlag::AmpersandNoBgInToken);
+        future_feature_flags::set(FeatureFlag::AmpersandNoBgInToken, true);
         let _restore_saved_flag = ScopeGuard::new((), |_| {
-            future_feature_flags::set(FeatureFlag::ampersand_nobg_in_token, saved_flag);
+            future_feature_flags::set(FeatureFlag::AmpersandNoBgInToken, saved_flag);
         });
 
         let fg = HighlightSpec::with_fg;
@@ -1829,4 +1841,29 @@ mod tests {
             );
         }
     }
+
+    #[test]
+    #[serial]
+    fn test_resolve_role() {
+        let _cleanup = test_init();
+        let parser = TestParser::new();
+        let vars = parser.vars();
+
+        let set = |var: &wstr, value: Vec<WString>| {
+            vars.set(var, EnvMode::LOCAL, value);
+        };
+        set(L!("fish_color_normal"), vec![L!("normal").into()]);
+        set(
+            L!("fish_color_command"),
+            vec![L!("red").into(), L!("--bold").into()],
+        );
+        set(L!("fish_color_keyword"), vec![L!("--theme=default").into()]);
+
+        let keyword_spec = HighlightSpec::with_both(HighlightRole::keyword);
+        let face = HighlightColorResolver::resolve_spec_uncached(&keyword_spec, vars);
+
+        let command_face =
+            parse_text_face_for_highlight(&vars.get(L!("fish_color_command")).unwrap()).unwrap();
+        assert_eq!(face, command_face);
+    }
 }
