@@ -31,6 +31,7 @@ use std::{
     fs::File,
     io::{BufRead, Read, Write},
     mem::MaybeUninit,
+    num::NonZeroUsize,
     ops::ControlFlow,
     sync::{Arc, Mutex, MutexGuard},
     time::{Duration, SystemTime, UNIX_EPOCH},
@@ -47,20 +48,21 @@ use crate::{
     env::{EnvMode, EnvStack, Environment},
     expand::{ExpandFlags, expand_one},
     fds::wopen_cloexec,
-    flog::{FLOG, FLOGF},
+    flog::{flog, flogf},
     fs::fsync,
     history::file::{HistoryFile, RawHistoryFile, append_history_item_to_buffer},
     io::IoStreams,
+    localization::wgettext_fmt,
     operation_context::{EXPANSION_LIMIT_BACKGROUND, OperationContext},
     parse_constants::{ParseTreeFlags, StatementDecoration},
     parse_util::{parse_util_detect_errors, parse_util_unescape_wildcards},
     path::{path_get_config, path_get_data, path_is_valid},
+    prelude::*,
     threads::assert_is_background_thread,
-    util::{find_subslice, get_rng},
-    wchar::prelude::*,
+    util::find_subslice,
     wcstringutil::subsequence_in_string,
     wildcard::{ANY_STRING, wildcard_match},
-    wutil::{FileId, INVALID_FILE_ID, file_id_for_file, wgettext_fmt, wrealpath, wstat, wunlink},
+    wutil::{FileId, INVALID_FILE_ID, file_id_for_file, wrealpath, wstat, wunlink},
 };
 
 #[derive(Clone, Copy, Debug, PartialEq, Eq)]
@@ -105,12 +107,6 @@ use super::file::time_to_seconds;
 /// This is the history session ID we use by default if the user has not set env var fish_history.
 const DFLT_FISH_HISTORY_SESSION_ID: &wstr = L!("fish");
 
-/// When we rewrite the history, the number of items we keep.
-const HISTORY_SAVE_MAX: usize = 1024 * 256;
-
-/// Default buffer size for flushing to the history file.
-const HISTORY_OUTPUT_BUFFER_SIZE: usize = 64 * 1024;
-
 pub const VACUUM_FREQUENCY: usize = 25;
 
 /// Output the contents `buffer` to `file` and clear the `buffer`.
@@ -141,7 +137,7 @@ impl Drop for TimeProfiler {
             let ns_per_ms = 1_000_000;
             let ms = duration.as_millis();
             let ns = duration.as_nanos() - (ms * ns_per_ms);
-            FLOGF!(
+            flogf!(
                 profile_history,
                 "%s: %d.%06d ms",
                 self.what,
@@ -149,7 +145,7 @@ impl Drop for TimeProfiler {
                 ns as u32
             )
         } else {
-            FLOGF!(profile_history, "%s: ??? ms", self.what)
+            flogf!(profile_history, "%s: ??? ms", self.what)
         }
     }
 }
@@ -420,9 +416,9 @@ impl HistoryImpl {
     /// Loads old items if necessary.
     /// Return a reference to the loaded history file.
     fn load_old_if_needed(&mut self) -> &HistoryFile {
-        if self.file_contents.is_some() {
-            return self.file_contents.as_ref().unwrap();
-        };
+        if let Some(ref file_contents) = self.file_contents {
+            return file_contents;
+        }
         let Ok(Some(history_path)) = self.history_file_path() else {
             return self.file_contents.insert(HistoryFile::create_empty());
         };
@@ -433,7 +429,7 @@ impl HistoryImpl {
                 self.history_file_id = file_id;
                 let _profiler = TimeProfiler::new("populate_from_file_contents");
                 let file_contents = history_file.decode(Some(self.boundary_timestamp));
-                FLOGF!(
+                flogf!(
                     history,
                     "Loaded %u old items",
                     file_contents.offsets().len()
@@ -441,7 +437,7 @@ impl HistoryImpl {
                 file_contents
             }
             Err(e) => {
-                FLOG!(history_file, "Error reading from history file:", e);
+                flog!(history_file, "Error reading from history file:", e);
                 HistoryFile::create_empty()
             }
         };
@@ -501,7 +497,10 @@ impl HistoryImpl {
         // We are reading FROM existing_file and writing TO dst
 
         // Make an LRU cache to save only the last N elements.
-        let mut lru = LruCache::new(HISTORY_SAVE_MAX.try_into().unwrap());
+
+        /// When we rewrite the history, the number of items we keep.
+        const HISTORY_SAVE_MAX: NonZeroUsize = NonZeroUsize::new(1024 * 256).unwrap();
+        let mut lru = LruCache::new(HISTORY_SAVE_MAX);
 
         // Read in existing items (which may have changed out from underneath us, so don't trust our
         // old file contents).
@@ -549,6 +548,8 @@ impl HistoryImpl {
         let mut items: Vec<_> = lru.into_iter().map(|(_key, item)| item).collect();
         items.sort_by_key(HistoryItem::timestamp);
 
+        /// Default buffer size for flushing to the history file.
+        const HISTORY_OUTPUT_BUFFER_SIZE: usize = 64 * 1024;
         // Write them out.
         let mut err = None;
         let mut buffer = Vec::with_capacity(HISTORY_OUTPUT_BUFFER_SIZE + 128);
@@ -565,7 +566,7 @@ impl HistoryImpl {
             }
         }
         if let Some(err) = err {
-            FLOG!(
+            flog!(
                 history_file,
                 "Error writing to temporary history file:",
                 err
@@ -578,7 +579,7 @@ impl HistoryImpl {
 
     /// Saves history by rewriting the file.
     fn save_internal_via_rewrite(&mut self, history_path: &wstr) -> std::io::Result<()> {
-        FLOGF!(
+        flogf!(
             history,
             "Saving %u items via rewrite",
             self.new_items.len() - self.first_unwritten_new_item_index
@@ -611,7 +612,7 @@ impl HistoryImpl {
 
     /// Saves history by appending to the file.
     fn save_internal_via_appending(&mut self, history_path: &wstr) -> std::io::Result<()> {
-        FLOGF!(
+        flogf!(
             history,
             "Saving %u items via appending",
             self.new_items.len() - self.first_unwritten_new_item_index
@@ -694,7 +695,7 @@ impl HistoryImpl {
         let history_path = match self.history_file_path() {
             Ok(history_path) => history_path.unwrap(),
             Err(e) => {
-                FLOG!(history, "Saving history failed:", e);
+                flog!(history, "Saving history failed:", e);
                 return;
             }
         };
@@ -705,7 +706,7 @@ impl HistoryImpl {
         if !vacuum && self.deleted_items.is_empty() {
             // Try doing a fast append.
             if let Err(e) = self.save_internal_via_appending(&history_path) {
-                FLOG!(history, "Appending to history failed:", e);
+                flog!(history, "Appending to history failed:", e);
             } else {
                 ok = true;
             }
@@ -713,7 +714,7 @@ impl HistoryImpl {
         if !ok {
             // We did not or could not append; rewrite the file ("vacuum" it).
             if let Err(e) = self.save_internal_via_rewrite(&history_path) {
-                FLOG!(history, "Rewriting history failed:", e)
+                flog!(history, "Rewriting history failed:", e)
             }
         }
     }
@@ -731,7 +732,7 @@ impl HistoryImpl {
         // the counter.
         let countdown_to_vacuum = self
             .countdown_to_vacuum
-            .get_or_insert_with(|| get_rng().gen_range(0..VACUUM_FREQUENCY));
+            .get_or_insert_with(|| rand::rng().random_range(0..VACUUM_FREQUENCY));
 
         // Determine if we're going to vacuum.
         let mut vacuum = false;
@@ -894,7 +895,7 @@ impl HistoryImpl {
         ) {
             Ok(file) => file,
             Err(err) => {
-                FLOG!(history_file, "Error when writing history file:", err);
+                flog!(history_file, "Error when writing history file:", err);
                 return;
             }
         };
@@ -906,7 +907,7 @@ impl HistoryImpl {
             }
 
             if let Err(err) = dst_file.write_all(&buf[..n]) {
-                FLOG!(history_file, "Error when writing history file:", err);
+                flog!(history_file, "Error when writing history file:", err);
                 break;
             }
         }
@@ -1086,7 +1087,7 @@ impl HistoryImpl {
 
 fn string_could_be_path(potential_path: &wstr) -> bool {
     // Assume that things with leading dashes aren't paths.
-    return !(potential_path.is_empty() || potential_path.starts_with('-'));
+    !(potential_path.is_empty() || potential_path.starts_with('-'))
 }
 
 /// Perform a search of `hist` for `search_string`. Invoke a function `func` for each match. If
@@ -1138,7 +1139,7 @@ fn format_history_record(
             let mut timestamp_str = [0_u8; MAX_TIMESTAMP_LENGTH];
             if unsafe {
                 libc::strftime(
-                    &mut timestamp_str[0] as *mut u8 as *mut libc::c_char,
+                    timestamp_str.as_mut_ptr().cast(),
                     MAX_TIMESTAMP_LENGTH,
                     show_time_format.as_ptr(),
                     timestamp.as_ptr(),
@@ -1255,7 +1256,7 @@ impl History {
     /// determine which arguments are paths. Arguments may be expanded (e.g. with PWD and variables)
     /// using the given `vars`. The item has the given `persist_mode`.
     pub fn add_pending_with_file_detection(
-        self: Arc<Self>,
+        self: &Arc<Self>,
         s: &wstr,
         vars: &EnvStack,
         persist_mode: PersistenceMode, /*=disk*/
@@ -1284,7 +1285,7 @@ impl History {
                 // Also skip it for 'echo'. This is because echo doesn't take file paths, but also
                 // because the history file test wants to find the commands in the history file
                 // immediately after running them, so it can't tolerate the asynchronous file detection.
-                if stmt.decoration() == StatementDecoration::exec {
+                if stmt.decoration() == StatementDecoration::Exec {
                     needs_sync_write = true;
                 }
 
@@ -1317,10 +1318,11 @@ impl History {
             let thread_pool = Arc::clone(&imp.thread_pool);
             drop(imp);
             let vars_snapshot = vars.snapshot();
+            let self_clone = Arc::clone(self);
             thread_pool.perform(move || {
                 // Don't hold the lock while we perform this file detection.
                 let valid_file_paths = expand_and_detect_paths(potential_paths, &vars_snapshot);
-                let mut imp = self.imp();
+                let mut imp = self_clone.imp();
                 if !valid_file_paths.is_empty() {
                     imp.set_valid_file_paths(valid_file_paths, &snapshot_item);
                 }
@@ -1380,7 +1382,7 @@ impl History {
                 collected.push(formatted_record);
             } else {
                 // We can output this immediately.
-                if !streams.out.append(formatted_record) {
+                if !streams.out.append(&formatted_record) {
                     // This can happen if the user hit Ctrl-C to abort (maybe after the first page?).
                     output_error = true;
                     return ControlFlow::Break(());
@@ -1425,7 +1427,7 @@ impl History {
                 break;
             }
 
-            if !streams.out.append(item) {
+            if !streams.out.append(&item) {
                 // Don't force an error if output was aborted (typically via Ctrl-C/SIGINT); just don't
                 // try writing any more.
                 output_error = true;
@@ -1679,7 +1681,7 @@ pub fn history_session_id_from_var(history_name_var: Option<EnvVar>) -> WString
     if session_id.is_empty() || valid_var_name(&session_id) {
         session_id
     } else {
-        FLOG!(
+        flog!(
             error,
             wgettext_fmt!(
                 "History session ID '%s' is not a valid variable name. Falling back to `%s`.",
@@ -1778,13 +1780,12 @@ mod tests {
     use crate::env::{EnvMode, EnvStack};
     use crate::fs::{LockedFile, WriteMethod};
     use crate::path::path_get_data;
+    use crate::prelude::*;
     use crate::tests::prelude::*;
-    use crate::util::get_rng;
-    use crate::wchar::prelude::*;
     use crate::wcstringutil::{string_prefixes_string, string_prefixes_string_case_insensitive};
     use fish_build_helper::workspace_root;
     use rand::Rng;
-    use rand::rngs::SmallRng;
+    use rand::rngs::ThreadRng;
     use std::collections::VecDeque;
     use std::io::BufReader;
     use std::os::unix::ffi::OsStrExt;
@@ -1806,12 +1807,13 @@ mod tests {
         false
     }
 
-    fn random_string(rng: &mut SmallRng) -> WString {
+    fn random_string(rng: &mut ThreadRng) -> WString {
         let mut result = WString::new();
-        let max = rng.gen_range(1..=32);
+        let max = rng.random_range(1..=32);
         for _ in 0..max {
-            let c = char::from_u32(u32::try_from(1 + rng.gen_range(0..ESCAPE_TEST_CHAR)).unwrap())
-                .unwrap();
+            let c =
+                char::from_u32(u32::try_from(1 + rng.random_range(0..ESCAPE_TEST_CHAR)).unwrap())
+                    .unwrap();
             result.push(c);
         }
         result
@@ -1927,7 +1929,7 @@ mod tests {
         let mut after: VecDeque<HistoryItem> = VecDeque::new();
         history.clear();
         let max = 100;
-        let mut rng = get_rng();
+        let mut rng = rand::rng();
         for i in 1..=max {
             // Generate a value.
             let mut value = WString::from_str("test item ") + &i.to_wstring()[..];
@@ -1938,7 +1940,7 @@ mod tests {
             }
 
             // Generate some paths.
-            let paths: PathList = (0..rng.gen_range(0..6))
+            let paths: PathList = (0..rng.random_range(0..6))
                 .map(|_| random_string(&mut rng))
                 .collect();
 
@@ -2015,11 +2017,6 @@ mod tests {
     fn test_history_races() {
         let _cleanup = test_init();
 
-        // Fail nearly every time on Cygwin (probably caused by flock issue, see #11933)
-        if cfg!(cygwin) {
-            return;
-        }
-
         let tmp_path = std::env::current_dir()
             .unwrap()
             .join("history-races-test-balloon");
@@ -2279,47 +2276,47 @@ mod tests {
         let history = History::with_name(L!("path_detection"));
         history.clear();
         assert_eq!(history.size(), 0);
-        history.clone().add_pending_with_file_detection(
+        history.add_pending_with_file_detection(
             L!("cmd0 not/a/valid/path"),
             &test_vars,
             PersistenceMode::Disk,
         );
-        history.clone().add_pending_with_file_detection(
+        history.add_pending_with_file_detection(
             &(L!("cmd1 ").to_owned() + filename),
             &test_vars,
             PersistenceMode::Disk,
         );
-        history.clone().add_pending_with_file_detection(
+        history.add_pending_with_file_detection(
             &(L!("cmd2 ").to_owned() + &wfile_path[..]),
             &test_vars,
             PersistenceMode::Disk,
         );
-        history.clone().add_pending_with_file_detection(
+        history.add_pending_with_file_detection(
             &(L!("cmd3  $HOME/").to_owned() + filename),
             &test_vars,
             PersistenceMode::Disk,
         );
-        history.clone().add_pending_with_file_detection(
+        history.add_pending_with_file_detection(
             L!("cmd4  $HOME/notafile"),
             &test_vars,
             PersistenceMode::Disk,
         );
-        history.clone().add_pending_with_file_detection(
+        history.add_pending_with_file_detection(
             &(L!("cmd5  ~/").to_owned() + filename),
             &test_vars,
             PersistenceMode::Disk,
         );
-        history.clone().add_pending_with_file_detection(
+        history.add_pending_with_file_detection(
             L!("cmd6  ~/notafile"),
             &test_vars,
             PersistenceMode::Disk,
         );
-        history.clone().add_pending_with_file_detection(
+        history.add_pending_with_file_detection(
             L!("cmd7  ~/*f*"),
             &test_vars,
             PersistenceMode::Disk,
         );
-        history.clone().add_pending_with_file_detection(
+        history.add_pending_with_file_detection(
             L!("cmd8  ~/*zzz*"),
             &test_vars,
             PersistenceMode::Disk,
