@@ -7,11 +7,9 @@
 //! The current implementation is less smart than ncurses allows and can not for example move blocks
 //! of text around to handle text insertion.
 
-use crate::FLOG;
 use crate::editable_line::line_at_cursor;
 use crate::key::ViewportPosition;
 use crate::pager::{PAGER_MIN_HEIGHT, PageRendering, Pager};
-use std::borrow::Cow;
 use std::cell::RefCell;
 use std::collections::LinkedList;
 use std::io::Write;
@@ -24,23 +22,23 @@ use std::time::SystemTime;
 use libc::{ONLCR, STDERR_FILENO, STDOUT_FILENO};
 
 use crate::common::{
-    bytes2wcstring, get_ellipsis_char, get_omitted_newline_str, get_omitted_newline_width,
+    get_ellipsis_char, get_omitted_newline_str, get_omitted_newline_width,
     has_working_tty_timestamps, shell_modes, wcs2bytes, write_loop,
 };
 use crate::env::Environment;
-use crate::fallback::fish_wcwidth;
-use crate::flog::FLOGF;
+use crate::flog::{flog, flogf};
 use crate::global_safety::RelaxedAtomicBool;
 use crate::highlight::{HighlightColorResolver, HighlightRole, HighlightSpec};
+use crate::prelude::*;
 use crate::terminal::TerminalCommand::{
     self, ClearToEndOfLine, ClearToEndOfScreen, CursorDown, CursorLeft, CursorMove, CursorRight,
-    CursorUp, EnterDimMode, ExitAttributeMode, Osc133PromptStart, ScrollContentUp,
+    CursorUp, EnterDimMode, ExitAttributeMode, Osc133PromptEnd, Osc133PromptStart, ScrollContentUp,
 };
 use crate::terminal::{BufferedOutputter, CardinalDirection, Output, Outputter, use_terminfo};
 use crate::termsize::Termsize;
-use crate::wchar::prelude::*;
 use crate::wcstringutil::{fish_wcwidth_visible, string_prefixes_string};
 use crate::wutil::fstat;
+use fish_fallback::fish_wcwidth;
 
 #[derive(Copy, Clone, Default)]
 pub enum CharOffset {
@@ -302,7 +300,7 @@ impl Screen {
         let screen_width = curr_termsize.width();
         let screen_height = curr_termsize.height();
         static REPAINTS: AtomicU32 = AtomicU32::new(0);
-        FLOGF!(
+        flogf!(
             screen,
             "Repaint %u",
             1 + REPAINTS.fetch_add(1, std::sync::atomic::Ordering::Relaxed)
@@ -435,15 +433,13 @@ impl Screen {
                 if is_final_rendering {
                     usize::MAX
                 } else {
-                    scrolled_cursor
-                        .map(|sc| {
-                            if sc.scroll_amount != 0 {
-                                sc.cursor.y
-                            } else {
-                                screen_height - 1
-                            }
-                        })
-                        .unwrap_or(usize::MAX)
+                    scrolled_cursor.map_or(usize::MAX, |sc| {
+                        if sc.scroll_amount != 0 {
+                            sc.cursor.y
+                        } else {
+                            screen_height - 1
+                        }
+                    })
                 },
                 effective_commandline.as_char_slice()[i],
                 colors[i],
@@ -564,12 +560,10 @@ impl Screen {
     }
 
     pub fn push_to_scrollback(&mut self) {
-        let Some(viewport_cursor_y) = self.viewport_y else {
+        let Some(lines_to_scroll) = self.viewport_y else {
             return;
         };
-        FLOG!(reader, "Pushing to scrollback");
-        let lines_to_scroll = self.command_line_y_given_cursor_y(viewport_cursor_y);
-        self.set_position_in_viewport("scrollback-push", Some(0));
+        flog!(reader, "Pushing to scrollback");
         if lines_to_scroll == 0 {
             return;
         }
@@ -578,10 +572,11 @@ impl Screen {
         out.write_command(ScrollContentUp(lines_to_scroll));
         // Reposition cursor.
         out.write_command(CursorMove(CardinalDirection::Up, lines_to_scroll));
+        self.set_position_in_viewport("scrollback-push", Some(0));
     }
 
     pub fn set_position_in_viewport(&mut self, whence: &str, viewport_y: Option<usize>) {
-        FLOGF!(
+        flogf!(
             reader,
             "Setting screen y to %s due to %s",
             viewport_y.map_or("<none>".to_string(), |y| format!("{y}")),
@@ -597,7 +592,7 @@ impl Screen {
         let actual_lines = self.actual.line_count();
         let remaining_vertical_space = screen_height.saturating_sub(actual_lines);
         if viewport_y > remaining_vertical_space {
-            FLOGF!(
+            flogf!(
                 reader,
                 "printing %u lines at y=%u would exceed window height (%u); \
                      assuming the extra lines have been pushed to scrollback, setting screen y to %d",
@@ -613,7 +608,7 @@ impl Screen {
     pub fn command_line_y_given_cursor_y(&mut self, viewport_cursor_y: usize) -> usize {
         let prompt_y = viewport_cursor_y.checked_sub(self.actual.cursor.y);
         prompt_y.unwrap_or_else(|| {
-            FLOG!(
+            flog!(
                 reader,
                 "Reported cursor line index",
                 viewport_cursor_y,
@@ -631,22 +626,21 @@ impl Screen {
         let Some(viewport_y) = self.viewport_y else {
             return CharOffset::None;
         };
-        let viewport_prompt_y = self.command_line_y_given_cursor_y(viewport_y);
         let y = viewport_position
             .y
-            .checked_sub(viewport_prompt_y)
+            .checked_sub(viewport_y)
             .unwrap_or_else(|| {
-                FLOG!(
+                flog!(
                     reader,
                     "Given y",
                     viewport_position.y,
                     "exceeds the prompt's y",
-                    viewport_prompt_y,
+                    viewport_y,
                     "inferred from reported cursor position",
                 );
                 0
             })
-            .max(self.actual.visible_prompt_lines - 1)
+            .max(self.actual.visible_prompt_lines.saturating_sub(1))
             .min(self.actual.line_count() - 1);
         let line = self.actual.line(y);
         let x = viewport_position.x.max(line.indentation);
@@ -659,8 +653,7 @@ impl Screen {
             } else {
                 None
             })
-            .map(|char| char.offset_in_cmdline)
-            .unwrap_or(CharOffset::Pointer(0));
+            .map_or(CharOffset::Pointer(0), |char| char.offset_in_cmdline);
         match offset {
             CharOffset::Cmd(value) if x >= line.len() => CharOffset::Cmd(value + 1),
             CharOffset::Pager(_) if x >= line.len() => CharOffset::None,
@@ -672,98 +665,102 @@ impl Screen {
     /// abandoning the current line and going to the next line.
     /// If clear_to_eos is set,
     /// The screen width must be provided for the PROMPT_SP hack.
-    pub fn reset_abandoning_line(&mut self, screen_width: usize) {
+    pub fn reset_abandoning_line(&mut self, screen_width: Option<usize>) {
         self.actual.cursor.y = 0;
         self.actual.clear_lines();
         self.actual_left_prompt = None;
         self.need_clear_lines = true;
 
-        // Do the PROMPT_SP hack.
-        let mut abandon_line_string = WString::with_capacity(screen_width + 32);
-
-        // Don't need to check for fish_wcwidth errors; this is done when setting up
-        // omitted_newline_char in common.rs.
-        let non_space_width = get_omitted_newline_width();
-        // We do `>` rather than `>=` because the code below might require one extra space.
-        if screen_width > non_space_width {
-            if use_terminfo() {
-                use crate::terminal::tparm1;
-                use std::ffi::CString;
-                let term = crate::terminal::term();
-                let mut justgrey = true;
-                let add = |abandon_line_string: &mut WString, s: Option<CString>| {
-                    let Some(s) = s else {
-                        return false;
-                    };
-                    abandon_line_string.push_utfstr(&bytes2wcstring(s.as_bytes()));
-                    true
-                };
-                if let Some(enter_dim_mode) = term.enter_dim_mode.as_ref() {
-                    if add(&mut abandon_line_string, Some(enter_dim_mode.clone())) {
-                        // Use dim if they have it, so the color will be based on their actual normal
-                        // color and the background of the terminal.
-                        justgrey = false;
-                    }
-                }
-                if let (true, Some(set_a_foreground)) = (justgrey, term.set_a_foreground.as_ref()) {
-                    let max_colors = term.max_colors.unwrap_or_default();
-                    if max_colors >= 238 {
-                        // draw the string in a particular grey
-                        add(&mut abandon_line_string, tparm1(set_a_foreground, 237));
-                    } else if max_colors >= 9 {
-                        // bright black (the ninth color, looks grey)
-                        add(&mut abandon_line_string, tparm1(set_a_foreground, 8));
-                    } else if max_colors >= 2 {
-                        if let Some(enter_bold_mode) = term.enter_bold_mode.as_ref() {
-                            // we might still get that color by setting black and going bold for bright
-                            add(&mut abandon_line_string, Some(enter_bold_mode.clone()));
-                            add(&mut abandon_line_string, tparm1(set_a_foreground, 0));
-                        }
-                    }
-                }
-            } else {
-                let mut tmp = Vec::<u8>::new();
-                tmp.write_command(EnterDimMode);
-                abandon_line_string.push_utfstr(&bytes2wcstring(&tmp));
-            }
-
-            abandon_line_string.push_utfstr(&get_omitted_newline_str());
-
-            // normal text ANSI escape sequence
-            let mut tmp = Vec::<u8>::new();
-            tmp.write_command(ExitAttributeMode);
-            abandon_line_string.push_utfstr(&bytes2wcstring(&tmp));
-
-            for _ in 0..screen_width - non_space_width {
-                abandon_line_string.push(' ');
-            }
-        }
-
-        abandon_line_string.push('\r');
-        abandon_line_string.push_utfstr(get_omitted_newline_str());
-        // Now we are certainly on a new line. But we may have dropped the omitted newline char on
-        // it. So append enough spaces to overwrite the omitted newline char, and then clear all the
-        // spaces from the new line.
-        for _ in 0..non_space_width {
-            abandon_line_string.push(' ');
-        }
-        abandon_line_string.push('\r');
-        // Clear entire line. Zsh doesn't do this. Fish added this with commit 4417a6ee: If you have
-        // a prompt preceded by a new line, you'll get a line full of spaces instead of an empty
-        // line above your prompt. This doesn't make a difference in normal usage, but copying and
-        // pasting your terminal log becomes a pain. This commit clears that line, making it an
-        // actual empty line.
-        let mut tmp = Vec::<u8>::new();
-        tmp.write_command(ClearToEndOfLine);
-        abandon_line_string.push_utfstr(&bytes2wcstring(&tmp));
-
-        let narrow_abandon_line_string = wcs2bytes(&abandon_line_string);
-        let _ = write_loop(&STDOUT_FILENO, &narrow_abandon_line_string);
+        let _ = write_loop(&STDOUT_FILENO, &abandon_line_string(screen_width));
         self.actual.cursor.x = 0;
 
         self.save_status();
     }
+}
 
+fn abandon_line_string(screen_width: Option<usize>) -> Vec<u8> {
+    use std::iter::repeat_n;
+
+    let Some(screen_width) = screen_width else {
+        return vec![b'\r'];
+    };
+
+    let mut abandon_line_string = Vec::with_capacity(screen_width + 32);
+
+    // Do the PROMPT_SP hack.
+    // Don't need to check for fish_wcwidth errors; this is done when setting up
+    // omitted_newline_char in common.rs.
+    let non_space_width = get_omitted_newline_width();
+    // We do `>` rather than `>=` because the code below might require one extra space.
+    if screen_width > non_space_width {
+        if use_terminfo() {
+            use crate::terminal::tparm1;
+            use std::ffi::CString;
+            let term = crate::terminal::term();
+            let mut justgrey = true;
+            let add = |abandon_line_string: &mut Vec<u8>, s: Option<CString>| {
+                let Some(s) = s else {
+                    return false;
+                };
+                abandon_line_string.extend(s.as_bytes());
+                true
+            };
+            if let Some(enter_dim_mode) = term.enter_dim_mode.as_ref() {
+                if add(&mut abandon_line_string, Some(enter_dim_mode.clone())) {
+                    // Use dim if they have it, so the color will be based on their actual normal
+                    // color and the background of the terminal.
+                    justgrey = false;
+                }
+            }
+            if let (true, Some(set_a_foreground)) = (justgrey, term.set_a_foreground.as_ref()) {
+                let max_colors = term.max_colors.unwrap_or_default();
+                if max_colors >= 238 {
+                    // draw the string in a particular grey
+                    add(&mut abandon_line_string, tparm1(set_a_foreground, 237));
+                } else if max_colors >= 9 {
+                    // bright black (the ninth color, looks grey)
+                    add(&mut abandon_line_string, tparm1(set_a_foreground, 8));
+                } else if max_colors >= 2 {
+                    if let Some(enter_bold_mode) = term.enter_bold_mode.as_ref() {
+                        // we might still get that color by setting black and going bold for bright
+                        add(&mut abandon_line_string, Some(enter_bold_mode.clone()));
+                        add(&mut abandon_line_string, tparm1(set_a_foreground, 0));
+                    }
+                }
+            }
+        } else {
+            abandon_line_string.write_command(EnterDimMode);
+        }
+
+        abandon_line_string.extend_from_slice(get_omitted_newline_str().as_bytes());
+        abandon_line_string.write_command(ExitAttributeMode);
+        abandon_line_string.extend(repeat_n(b' ', screen_width - non_space_width));
+    }
+
+    abandon_line_string.push(b'\r');
+    abandon_line_string.extend_from_slice(get_omitted_newline_str().as_bytes());
+    // Now we are certainly on a new line. But we may have dropped the omitted newline char on
+    // it. So append enough spaces to overwrite the omitted newline char, and then clear all the
+    // spaces from the new line.
+    abandon_line_string.extend(repeat_n(b' ', non_space_width));
+    abandon_line_string.push(b'\r');
+    // Clear entire line. Zsh doesn't do this. Fish added this with commit 4417a6ee: If you have
+    // a prompt preceded by a new line, you'll get a line full of spaces instead of an empty
+    // line above your prompt. This doesn't make a difference in normal usage, but copying and
+    // pasting your terminal log becomes a pain. This commit clears that line, making it an
+    // actual empty line.
+    abandon_line_string.write_command(ClearToEndOfLine);
+    abandon_line_string.push(b'\r');
+    // Clear entire line. Zsh doesn't do this. Fish added this with commit 4417a6ee: If you have
+    // a prompt preceded by a new line, you'll get a line full of spaces instead of an empty
+    // line above your prompt. This doesn't make a difference in normal usage, but copying and
+    // pasting your terminal log becomes a pain. This commit clears that line, making it an
+    // actual empty line.
+    abandon_line_string.write_command(ClearToEndOfLine);
+    abandon_line_string
+}
+
+impl Screen {
     /// Stat stdout and stderr and save result as the current timestamp.
     /// This is used to avoid reacting to changes that we ourselves made to the screen.
     pub fn save_status(&mut self) {
@@ -1142,6 +1139,7 @@ impl Screen {
                 start = *left_prompt_layout.line_starts.last().unwrap();
             }
             self.write_str(&left_prompt[start..]);
+            self.write_command(Osc133PromptEnd);
             self.actual_left_prompt = Some(left_prompt.to_owned());
             self.actual.cursor.x = prompt_last_line_width;
             self.actual.cursor.y = prompt_last_line;
@@ -1155,6 +1153,7 @@ impl Screen {
             // If we refreshed and prompt is not visible, print prompt marker
             self.r#move(0, 0);
             self.write_command(Osc133PromptStart);
+            self.write_command(Osc133PromptEnd);
             self.actual_left_prompt = Some(left_prompt.to_owned());
         }
 
@@ -1210,8 +1209,9 @@ impl Screen {
                         ClearToEndOfLine
                     });
                     if i == 0 && start_pos == 0 {
-                        // Restore prompt marker if we deleted it
+                        // Restore prompt markers if we deleted them
                         self.write_command(Osc133PromptStart);
+                        self.write_command(Osc133PromptEnd);
                     }
                     has_cleared_screen = should_clear_screen_this_line;
                     has_cleared_line = true;
@@ -1949,21 +1949,6 @@ struct ScreenLayout {
     pub(crate) autosuggestion: WString,
 }
 
-// Given a vector whose indexes are offsets and whose values are the widths of the string if
-// truncated at that offset, return the offset that fits in the given width. Returns
-// width_by_offset.size() - 1 if they all fit. The first value in width_by_offset is assumed to be
-// 0.
-fn truncation_offset_for_width(str: &wstr, max_width: usize) -> usize {
-    let mut i = 0;
-    let mut width = 0;
-    while i < str.len() && width <= max_width {
-        width += wcwidth_rendered_min_0(str.char_at(i));
-        i += 1;
-    }
-    // i is the first index that did not fit; i - 1 is therefore the last that did.
-    i - 1
-}
-
 #[allow(clippy::too_many_arguments)]
 fn compute_layout(
     ellipsis_char: char,
@@ -2039,19 +2024,15 @@ fn compute_layout(
     // Now we should definitely fit.
     assert!(left_prompt_width + right_prompt_width <= screen_width);
 
-    // Truncate each logical line from the autosuggestion to fit on a single screen line.
-    // In future, we should truncate only once, at the end (#12004).
+    // Track each logical line from the autosuggestion so we can determine how much of it fits
+    // on screen. We allow the lines to soft wrap naturally and we only truncate vertically if
+    // we would exceed the screen height.
     let cursor_y = left_prompt_layout.line_starts.len() - 1
         + commandline_before_suggestion
             .chars()
             .filter(|&c| c == '\n')
             .count();
 
-    struct SuggestionLine<'a> {
-        available_autosuggest_space: usize,
-        autosuggestion_line: &'a wstr,
-        autosuggest_total_width: usize,
-    }
     let mut suggestion_lines = vec![];
 
     let mut available_vertical_space = screen_viewport_y.map_or(
@@ -2065,11 +2046,11 @@ fn compute_layout(
         .split(|&c| c == '\n')
         .enumerate()
     {
+        if available_vertical_space == 0 {
+            truncated_vertically = true;
+            break;
+        }
         let autosuggestion_line = wstr::from_char_slice(autosuggestion_line);
-        let autosuggest_total_width = autosuggestion_line
-            .chars()
-            .map(wcwidth_rendered_min_0)
-            .sum();
 
         // Calculate space available for autosuggestion.
         let indent_width = |pos| usize::try_from(indent[pos]).unwrap() * INDENT_STEP;
@@ -2083,80 +2064,82 @@ fn compute_layout(
             } else {
                 indent_width(suggestion_start - "\n".len())
             };
-        let available_horizontal_space = screen_width - (width % screen_width);
-
-        let suggestion_line_height =
-            if width >= screen_width || autosuggest_total_width >= available_horizontal_space {
-                // As per the comment above, we truncate and autosuggestion lines that would wrap.
-                // We truncate them at the very end of the screen, so they (barely) soft wrap,
-                // and take up two screen lines.
-                2
-            } else {
-                1
-            };
-        match available_vertical_space.checked_sub(suggestion_line_height) {
-            Some(lines) => available_vertical_space = lines,
-            None => {
-                truncated_vertically = true;
-                break;
+        available_vertical_space = available_vertical_space.saturating_sub(width / screen_width);
+        if available_vertical_space == 0 {
+            truncated_vertically = true;
+            break;
+        }
+        let column = width % screen_width;
+        fn consumed_lines_or_truncated_suggestion(
+            screen_width: usize,
+            available_vertical_space: usize,
+            mut column: usize,
+            autosuggestion_line: &wstr,
+        ) -> Result<usize, &wstr> {
+            let mut lines = 1;
+            for (i, ch) in autosuggestion_line.char_indices() {
+                let ch_width = wcwidth_rendered_min_0(ch);
+                let new_column = column + ch_width;
+                if new_column >= screen_width {
+                    column = 0;
+                    lines += 1;
+                }
+                let barely_softwrapped = new_column == screen_width;
+                if !barely_softwrapped {
+                    column += ch_width;
+                }
+                if lines > available_vertical_space {
+                    return Err(autosuggestion_line.slice_to(i));
+                }
             }
-        };
-
-        suggestion_lines.push(SuggestionLine {
-            available_autosuggest_space: available_horizontal_space,
-            autosuggestion_line,
-            autosuggest_total_width,
-        });
+            Ok(lines)
+        }
+        suggestion_lines.push(
+            match consumed_lines_or_truncated_suggestion(
+                screen_width,
+                available_vertical_space,
+                column,
+                autosuggestion_line,
+            ) {
+                Ok(lines) => {
+                    available_vertical_space -= lines;
+                    autosuggestion_line
+                }
+                Err(truncated) => {
+                    truncated_vertically = true;
+                    truncated
+                }
+            },
+        );
+        if truncated_vertically {
+            break;
+        }
 
         suggestion_start += autosuggestion_line.len() + "\n".len();
     }
 
     let mut autosuggestion = WString::new();
-    let mut erased = 0;
-    let mut suggestion_start = commandline_before_suggestion.len();
-    for (
-        line,
-        &SuggestionLine {
-            available_autosuggest_space,
-            autosuggestion_line,
-            autosuggest_total_width,
-        },
-    ) in suggestion_lines.iter().enumerate()
-    {
-        let truncated_suggestion_line;
-        let mut vertical_truncation_marker = None;
-        if autosuggest_total_width > 0 && autosuggest_total_width >= available_autosuggest_space {
-            // horizontal truncation
-            let truncation_offset =
-                truncation_offset_for_width(autosuggestion_line, available_autosuggest_space - 1);
-            truncated_suggestion_line = Cow::Owned(
-                autosuggestion_line[..truncation_offset].to_owned()
-                    + wstr::from_char_slice(&[ellipsis_char]),
-            );
-        } else if truncated_vertically && line == suggestion_lines.len() - 1 {
-            // vertical truncation
-            truncated_suggestion_line = Cow::Borrowed(autosuggestion_line);
-            vertical_truncation_marker = Some(ellipsis_char);
-        } else {
-            // no truncation
-            assert!(available_autosuggest_space >= autosuggest_total_width);
-            truncated_suggestion_line = Cow::Borrowed(autosuggestion_line);
-        }
-
-        let truncation_range = suggestion_start - erased + truncated_suggestion_line.len()
-            ..suggestion_start - erased + autosuggestion_line.len();
-        colors.drain(truncation_range.clone());
-        indent.drain(truncation_range.clone());
-        erased += truncation_range.len();
-        suggestion_start += autosuggestion_line.len() + "\n".len();
-        if line != 0 {
+    let mut displayed_len = 0;
+    for (line_idx, autosuggestion_line) in suggestion_lines.iter().enumerate() {
+        if line_idx != 0 {
             autosuggestion.push('\n');
+            displayed_len += "\n".len();
         }
-        autosuggestion.push_utfstr(&truncated_suggestion_line);
-        if let Some(extra) = vertical_truncation_marker {
-            autosuggestion.push(extra);
-            colors.insert(truncation_range.end, colors[truncation_range.end - 1]);
-            indent.insert(truncation_range.end, indent[truncation_range.end - 1]);
+        autosuggestion.push_utfstr(autosuggestion_line);
+        displayed_len += autosuggestion_line.len();
+    }
+
+    let total_autosuggestion_len = autosuggestion_str.len();
+    let truncated_chars = total_autosuggestion_len.saturating_sub(displayed_len);
+    if truncated_chars > 0 {
+        let suggestion_end = commandline_before_suggestion.len() + displayed_len;
+        colors.drain(suggestion_end..suggestion_end + truncated_chars);
+        indent.drain(suggestion_end..suggestion_end + truncated_chars);
+        if truncated_vertically && displayed_len > 0 {
+            let suggestion_last = suggestion_end - 1;
+            autosuggestion.push(ellipsis_char);
+            colors.insert(suggestion_end, colors[suggestion_last]);
+            indent.insert(suggestion_end, indent[suggestion_last]);
         }
     }
     result.autosuggestion = autosuggestion;
@@ -2192,11 +2175,11 @@ mod tests {
     use crate::common::get_ellipsis_char;
     use crate::highlight::HighlightSpec;
     use crate::parse_util::parse_util_compute_indents;
+    use crate::prelude::*;
     use crate::screen::{
         LayoutCache, PromptCacheEntry, PromptLayout, ScreenLayout, compute_layout,
     };
     use crate::tests::prelude::*;
-    use crate::wchar::prelude::*;
     use crate::wcstringutil::join_strings;
 
     #[test]
@@ -2498,7 +2481,7 @@ mod tests {
                 "left>",
                 5,
                 "<right",
-                " autosugges…",
+                " autosuggesTION",
             )
         );
         validate!(
@@ -2518,7 +2501,7 @@ mod tests {
                 "left>",
                 5,
                 "<right",
-                " autosuggestion t…",
+                " autosuggestion tRUNCATED",
             )
         );
         validate!(
@@ -2528,7 +2511,7 @@ mod tests {
                 "left>",
                 5,
                 "<right",
-                " autosuggesti…",
+                " autosuggestiON  TRUNCATED",
             )
         );
         let indent = validate!(
@@ -2538,10 +2521,10 @@ mod tests {
                 "left>",
                 5,
                 "<right",
-                " autosuggesti…",
+                " autosuggestiON  TRUNCATED",
             )
         );
-        assert_eq!(indent["if :\ncommand autosuggesti…\n".len()], 1);
+        assert_eq!(indent["if :\ncommand autosuggestiON  TRUNCATED\n".len()], 1);
 
         validate!(
             (
@@ -2550,7 +2533,7 @@ mod tests {
                 "left>",
                 5,
                 "",
-                " auto…",
+                " autoSUGGESTION",
             )
         );
         validate!(
@@ -2560,7 +2543,7 @@ mod tests {
                 "left>",
                 5,
                 "",
-                "…",
+                "s",
             )
         );
         validate!(
@@ -2570,7 +2553,7 @@ mod tests {
                 "left>",
                 5,
                 "",
-                "…",
+                "SUGGESTION",
             )
         );
         validate!(
@@ -2580,7 +2563,7 @@ mod tests {
                 "left>",
                 5,
                 "",
-                "uggestion long so…",
+                "uggestion long soFT WRAP",
             )
         );
         validate!(
@@ -2590,7 +2573,7 @@ mod tests {
                 "left>",
                 5,
                 "<right",
-                "and …",
+                "and AUTOSUGGESTION",
             )
         );
         validate!(
@@ -2600,7 +2583,7 @@ mod tests {
                 "left>",
                 5,
                 "<right",
-                "…",
+                "AUTOSUGGESTION",
             )
         );
         validate!( //
@@ -2610,7 +2593,7 @@ mod tests {
                 "left>",
                 5,
                 "<right",
-                "utosuggestion sof…",
+                "utosuggestion sofT WRAP",
             )
         );
         validate!(
@@ -2620,7 +2603,7 @@ mod tests {
                 "left>",
                 5,
                 "",
-                "and …",
+                "and AUTOSUGGESTION",
             )
         );
         validate!(
@@ -2630,7 +2613,7 @@ mod tests {
                 "left>",
                 5,
                 "",
-                "…",
+                "AUTOSUGGESTION",
             )
         );
         validate!(
@@ -2640,7 +2623,7 @@ mod tests {
                 "left>",
                 5,
                 "",
-                "utosuggestion sof…",
+                "utosuggestion sofT WRAP",
             )
         );
     }
