@@ -1,14 +1,15 @@
 // Generic output functions.
-use crate::FLOGF;
 use crate::color::{Color, Color24};
 use crate::common::ToCString;
 use crate::common::{self, EscapeStringStyle, escape_string, wcs2bytes, wcs2bytes_appending};
+use crate::flogf;
 use crate::future_feature_flags::{self, FeatureFlag};
+use crate::prelude::*;
 use crate::screen::{is_dumb, only_grayscale};
 use crate::text_face::{TextFace, TextStyling, UnderlineStyle};
 use crate::threads::MainThread;
-use crate::wchar::prelude::*;
 use bitflags::bitflags;
+use once_cell::sync::OnceCell;
 use std::cell::{RefCell, RefMut};
 use std::env;
 use std::ffi::{CStr, CString};
@@ -78,7 +79,7 @@ pub(crate) enum TerminalCommand<'a> {
     CursorRight,
     CursorMove(CardinalDirection, usize),
 
-    // Commands related to querying (used for backwards-incompatible features).
+    // Commands related to querying (used mainly for backwards-incompatible features).
     QueryPrimaryDeviceAttribute,
     QueryXtversion,
     QueryXtgettcap(&'static str),
@@ -103,12 +104,14 @@ pub(crate) enum TerminalCommand<'a> {
     // man pages (via "man_show_urls").
     Osc0WindowTitle(&'a [WString]),
     Osc1TabTitle(&'a [WString]),
-    Osc133CommandStart(&'a wstr),
     Osc133PromptStart,
+    Osc133PromptEnd,
+    Osc133CommandStart(&'a wstr),
     Osc133CommandFinished(libc::c_int),
 
     // Other terminal features
     QueryCursorPosition,
+    QueryBackgroundColor,
     ScrollContentUp(usize),
 
     DecsetShowCursor,
@@ -116,6 +119,8 @@ pub(crate) enum TerminalCommand<'a> {
     DecrstFocusReporting,
     DecsetBracketedPaste,
     DecrstBracketedPaste,
+    DecsetColorThemeReporting,
+    DecrstColorThemeReporting,
 }
 
 pub(crate) trait Output {
@@ -179,15 +184,19 @@ pub(crate) trait Output {
             Osc0WindowTitle(title) => osc_0_or_1_terminal_title(self, false, title),
             Osc1TabTitle(title) => osc_0_or_1_terminal_title(self, true, title),
             Osc133PromptStart => osc_133_prompt_start(self),
+            Osc133PromptEnd => osc_133_prompt_end(self),
             Osc133CommandStart(command) => osc_133_command_start(self, command),
             Osc133CommandFinished(s) => osc_133_command_finished(self, s),
             QueryCursorPosition => write(self, b"\x1b[6n"),
+            QueryBackgroundColor => write(self, b"\x1b]11;?\x1b\\"),
             ScrollContentUp(lines) => scroll_content_up(self, lines),
             DecsetShowCursor => write(self, b"\x1b[?25h"),
             DecsetFocusReporting => write(self, b"\x1b[?1004h"),
             DecrstFocusReporting => write(self, b"\x1b[?1004l"),
             DecsetBracketedPaste => write(self, b"\x1b[?2004h"),
             DecrstBracketedPaste => write(self, b"\x1b[?2004l"),
+            DecsetColorThemeReporting => write(self, b"\x1b[?2031h"),
+            DecrstColorThemeReporting => write(self, b"\x1b[?2031l"),
         }
     }
 }
@@ -216,7 +225,7 @@ fn maybe_terminfo(
 }
 
 pub(crate) fn use_terminfo() -> bool {
-    !future_feature_flags::test(FeatureFlag::ignore_terminfo) && TERM.lock().unwrap().is_some()
+    !future_feature_flags::test(FeatureFlag::IgnoreTerminfo) && TERM.lock().unwrap().is_some()
 }
 
 fn underline_mode(out: &mut impl Output, style: UnderlineStyle) -> bool {
@@ -364,7 +373,11 @@ impl<'a> std::fmt::Display for DisplayAsHex<'a> {
 }
 
 fn query_kitty_progressive_enhancements(out: &mut impl Output) -> bool {
-    if std::env::var_os("TERM").is_some_and(|term| term.as_os_str().as_bytes() == b"st-256color") {
+    #[allow(unused_parens)]
+    if (
+        // TODO(term-workaround)
+        std::env::var_os("TERM").is_some_and(|term| term.as_os_str().as_bytes() == b"st-256color")
+    ) {
         return false;
     }
     out.write_bytes(b"\x1b[?u");
@@ -381,15 +394,28 @@ fn osc_0_or_1_terminal_title(out: &mut impl Output, is_1: bool, title: &[WString
 }
 
 fn osc_133_prompt_start(out: &mut impl Output) -> bool {
-    if !future_feature_flags::test(FeatureFlag::mark_prompt) {
+    if !future_feature_flags::test(FeatureFlag::MarkPrompt) {
         return false;
     }
-    write_to_output!(out, "\x1b]133;A;click_events=1\x07");
+    static TEST_BALLOON: OnceCell<()> = OnceCell::new();
+    if TEST_BALLOON.set(()).is_ok() {
+        write_to_output!(out, "\x1b]133;A;click_events=1\x1b\\");
+    } else {
+        write_to_output!(out, "\x1b]133;A;click_events=1\x07");
+    }
+    true
+}
+
+fn osc_133_prompt_end(out: &mut impl Output) -> bool {
+    if !future_feature_flags::test(FeatureFlag::MarkPrompt) {
+        return false;
+    }
+    write_to_output!(out, "\x1b]133;B\x07");
     true
 }
 
 fn osc_133_command_start(out: &mut impl Output, command: &wstr) -> bool {
-    if !future_feature_flags::test(FeatureFlag::mark_prompt) {
+    if !future_feature_flags::test(FeatureFlag::MarkPrompt) {
         return false;
     }
     write_to_output!(
@@ -401,7 +427,7 @@ fn osc_133_command_start(out: &mut impl Output, command: &wstr) -> bool {
 }
 
 fn osc_133_command_finished(out: &mut impl Output, exit_status: libc::c_int) -> bool {
-    if !future_feature_flags::test(FeatureFlag::mark_prompt) {
+    if !future_feature_flags::test(FeatureFlag::MarkPrompt) {
         return false;
     }
     write_to_output!(out, "\x1b]133;D;{}\x07", exit_status);
@@ -861,7 +887,7 @@ pub fn setup() {
             let mut path = PathBuf::from(dir);
             path.push(first_char.clone());
             path.push(t.clone());
-            FLOGF!(term_support, "Trying path '%s'", path.to_str().unwrap());
+            flogf!(term_support, "Trying path '%s'", path.to_str().unwrap());
             if let Ok(db) = terminfo::Database::from_path(path) {
                 return Ok(db);
             }
@@ -903,8 +929,7 @@ fn get_num_cap(db: &terminfo::Database, code: &str) -> Option<usize> {
 /// Panics if the given code string does not contain exactly two bytes.
 fn get_flag_cap(db: &terminfo::Database, code: &str) -> bool {
     db.raw(code)
-        .map(|cap| matches!(cap, terminfo::Value::True))
-        .unwrap_or(false)
+        .is_some_and(|cap| matches!(cap, terminfo::Value::True))
 }
 
 /// Covers over tparm() with one parameter.
