@@ -1,9 +1,9 @@
 // Support for exposing the terminal size.
 use crate::common::assert_sync;
 use crate::env::{EnvMode, EnvVar, Environment};
-use crate::flog::FLOG;
+use crate::flog::flog;
 use crate::parser::Parser;
-use crate::wchar::prelude::*;
+use crate::prelude::*;
 use crate::wutil::fish_wcstoi;
 use std::mem::MaybeUninit;
 use std::num::NonZeroU16;
@@ -41,14 +41,14 @@ fn read_termsize_from_tty() -> Option<Termsize> {
         unsafe { winsize.assume_init() }
     };
     let width = NonZeroU16::new(winsize.ws_col).unwrap_or_else(|| {
-        FLOG!(
+        flog!(
             term_support,
             L!("Terminal has 0 columns, falling back to default width")
         );
         Termsize::DEFAULT_WIDTH
     });
     let height = NonZeroU16::new(winsize.ws_row).unwrap_or_else(|| {
-        FLOG!(
+        flog!(
             term_support,
             L!("Terminal has 0 rows, falling back to default height")
         );
