@@ -1,8 +1,9 @@
 //! Helper functions for working with wcstring.
 
 use crate::common::{get_ellipsis_char, get_ellipsis_str};
-use crate::fallback::{fish_wcwidth, wcscasecmp, wcscasecmp_fuzzy};
-use crate::wchar::{decode_byte_from_char, prelude::*};
+use crate::prelude::*;
+use fish_fallback::{fish_wcwidth, lowercase, lowercase_rev, wcscasecmp, wcscasecmp_fuzzy};
+use fish_wchar::decode_byte_from_char;
 
 /// Return the number of newlines in a string.
 pub fn count_newlines(s: &wstr) -> usize {
@@ -20,8 +21,9 @@ pub fn count_newlines(s: &wstr) -> usize {
 
 /// Test if a string prefixes another without regard to case. Returns true if a is a prefix of b.
 pub fn string_prefixes_string_case_insensitive(proposed_prefix: &wstr, value: &wstr) -> bool {
-    let prefix_size = proposed_prefix.len();
-    prefix_size <= value.len() && wcscasecmp(&value[..prefix_size], proposed_prefix).is_eq()
+    let mut proposed_prefix = lowercase(proposed_prefix.chars());
+    let value = lowercase(value.chars());
+    proposed_prefix.by_ref().zip(value).all(|(a, b)| a == b) && proposed_prefix.next().is_none()
 }
 
 pub fn string_prefixes_string_maybe_case_insensitive(
@@ -36,11 +38,19 @@ pub fn string_prefixes_string_maybe_case_insensitive(
     })(proposed_prefix, value)
 }
 
+/// Remove the optional executable extension if there is one
+/// Always returns None on non-Cygwin platforms
+pub fn strip_executable_suffix(path: &wstr) -> Option<&wstr> {
+    const DOT_EXE: &wstr = L!(".exe");
+    (cfg!(cygwin) && { string_suffixes_string_case_insensitive(DOT_EXE, path) })
+        .then(|| &path[..path.len() - DOT_EXE.len()])
+}
+
 /// Test if a string is a suffix of another.
 pub fn string_suffixes_string_case_insensitive(proposed_suffix: &wstr, value: &wstr) -> bool {
-    let suffix_size = proposed_suffix.len();
-    suffix_size <= value.len()
-        && wcscasecmp(&value[value.len() - suffix_size..], proposed_suffix).is_eq()
+    let mut proposed_suffix = lowercase_rev(proposed_suffix.chars());
+    let value = lowercase_rev(value.chars());
+    proposed_suffix.by_ref().zip(value).all(|(a, b)| a == b) && proposed_suffix.next().is_none()
 }
 
 /// Test if a string prefixes another. Returns true if a is a prefix of b.
@@ -140,13 +150,18 @@ pub enum CaseSensitivity {
 /// A lightweight value-type describing how closely a string fuzzy-matches another string.
 #[derive(Copy, Clone, Debug, Eq, PartialEq)]
 pub struct StringFuzzyMatch {
+    pub from_separator: bool,
     pub typ: ContainType,
     pub case_fold: CaseSensitivity,
 }
 
 impl StringFuzzyMatch {
     pub fn new(typ: ContainType, case_fold: CaseSensitivity) -> Self {
-        Self { typ, case_fold }
+        Self {
+            from_separator: false,
+            typ,
+            case_fold,
+        }
     }
     // Helper to return an exact match.
     #[inline(always)]
@@ -282,8 +297,10 @@ impl StringFuzzyMatch {
             self.case_fold
         };
 
-        // Type dominates fold.
-        effective_type as u32 * 8 + effective_case as u32
+        // Separator dominates type dominates fold.
+        ((self.from_separator as u32) << 4)
+            + ((effective_type as u32) << 2)
+            + (effective_case as u32)
     }
 }
 
@@ -297,11 +314,12 @@ pub fn string_fuzzy_match_string(
 }
 
 /// Implementation of wcs2bytes that accepts a callback.
+/// The first argument can be either a `&str` or `&wstr`.
 /// This invokes `func` with byte slices containing the UTF-8 encoding of the characters in the
 /// input, doing one invocation per character.
 /// If `func` returns false, it stops; otherwise it continues.
 /// Return false if the callback returned false, otherwise true.
-pub fn wcs2bytes_callback(input: &wstr, mut func: impl FnMut(&[u8]) -> bool) -> bool {
+pub fn str2bytes_callback(input: impl IntoCharIter, mut func: impl FnMut(&[u8]) -> bool) -> bool {
     // A `char` represents an Unicode scalar value, which takes up at most 4 bytes when encoded in UTF-8.
     let mut converted = [0_u8; 4];
 
@@ -350,8 +368,7 @@ pub fn split_string_tok<'val>(
         let next_sep = val[pos..]
             .iter()
             .position(|c| seps.contains(*c))
-            .map(|p| pos + p)
-            .unwrap_or(end);
+            .map_or(end, |p| pos + p);
         out.push(wstr::from_char_slice(&val[pos..next_sep]));
         // Note we skip exactly one sep here. This is because on the last iteration we retain all
         // but the first leading separators. This is historical.
@@ -513,8 +530,7 @@ impl<'a> Iterator for LineIterator<'a> {
         let newline_or_end = self.coll[self.current..]
             .iter()
             .position(|b| *b == b'\n')
-            .map(|pos| self.current + pos)
-            .unwrap_or(self.coll.len());
+            .map_or(self.coll.len(), |pos| self.current + pos);
         let result = &self.coll[self.current..newline_or_end];
         self.current = newline_or_end;
 
@@ -538,9 +554,43 @@ pub fn fish_wcwidth_visible(c: char) -> isize {
 mod tests {
     use super::{
         CaseSensitivity, ContainType, LineIterator, count_newlines, ifind, join_strings,
-        split_string_tok, string_fuzzy_match_string,
+        split_string_tok, string_fuzzy_match_string, string_prefixes_string_case_insensitive,
+        string_suffixes_string_case_insensitive,
     };
-    use crate::wchar::prelude::*;
+    use crate::prelude::*;
+
+    #[test]
+    fn test_string_prefixes_string_case_insensitive() {
+        macro_rules! validate {
+            ($prefix:literal, $s:literal, $expected:expr) => {
+                assert_eq!(
+                    string_prefixes_string_case_insensitive(L!($prefix), L!($s)),
+                    $expected
+                );
+            };
+        }
+        validate!("i", "i_", true);
+        validate!("İ", "i\u{307}_", true);
+        validate!("i\u{307}", "İ", true); // prefix is longer
+        validate!("i", "İ", true);
+    }
+
+    #[test]
+    fn test_string_suffixes_string_case_insensitive() {
+        macro_rules! validate {
+            ($suffix:literal, $s:literal, $expected:expr) => {
+                assert_eq!(
+                    string_suffixes_string_case_insensitive(L!($suffix), L!($s)),
+                    $expected
+                );
+            };
+        }
+        validate!("i", "_i", true);
+        validate!("i\u{307}", "İ", true);
+        validate!("İ", "i\u{307}", true); // suffix is longer
+        validate!("İ", "_İ", true);
+        validate!("i", "_İ", false);
+    }
 
     #[test]
     fn test_ifind() {
